@@ -1,16 +1,16 @@
 // -*- C++ -*-
 /* This file is part of
- * ====================================================== 
- * 
+ * ======================================================
+ *
  *           LyX, The Document Processor
  *
  *	     Copyright 1995 Matthias Ettrich
- *           Copyright 1995-1999 The LyX Team.
+ *           Copyright 1995-2001 The LyX Team.
  *
  *           This file is Copyright 1997
  *           Asger Alstrup
  *
- * ====================================================== 
+ * ======================================================
  */
 
 #ifndef CHKTEX_H
@@ -29,14 +29,15 @@ class TeXErrors;
 class Chktex {
 public:
 	/**
-	  cmd = the chktex command, file = name of the (temporary) latex file,
-	  path = name of the files original path.
-	  */
+	  @param cmd the chktex command.
+	  @param file name of the (temporary) latex file.
+	  @param path name of the files original path.
+	*/
 	Chktex(string const & cmd, string const & file,
 	       string const & path);
-	
+
 	/** Runs chktex.
-	  Returns -1 if fail, number of messages otherwise.
+	    @return -1 if fail, number of messages otherwise.
 	  */
 	int run(TeXErrors &);
 private:
@@ -48,7 +49,7 @@ private:
 
 	///
 	string file;
-	
+
 	///
 	string path;
 };
