@@ -43,13 +43,12 @@ public:
 	///
 	Floating const & getType(string const & t) const;
 	///
+	void erase(string const & t);
+	///
 	const_iterator operator[](string const & t) const;
 private:
 	///
 	List list;
 };
 
-///
-extern FloatList floatList;
-
 #endif
