@@ -12,14 +12,19 @@
 #ifndef LSTRING_H
 #define LSTRING_H
 
+#if 0
 #ifndef _CONFIG_H
 #error The <config.h> header should always be included before LString.h
 #endif
+#endif
 
 #ifndef USE_INCLUDED_STRING
+
 #include <string>
 using std::string;
+#define STRCONV(STR) STR
 #else
+
 #ifdef __STRING__
 #error The <string> header has been included before LString.h
 #else
@@ -28,5 +33,7 @@ using std::string;
 #include "support/lyxstring.h"
 // using lyx::string;
 typedef lyxstring string;
+#define STRCONV(STR) STR.c_str()
 #endif
+
 #endif
