@@ -19,23 +19,24 @@
 
 #include "LString.h"
 #include "undo.h"
-#include "undostack.h"
+#include "support/limited_stack.h"
+
 #include "lyxvc.h"
 #include "bufferparams.h"
 #include "texrow.h"
+#include "ParagraphList.h"
 #include "paragraph.h"
 
+#include <boost/shared_ptr.hpp>
+
 class BufferView;
 class LyXRC;
 class TeXErrors;
 class LaTeXFeatures;
 class Language;
 class ParIterator;
+class ParConstIterator;
 
-// When lyx 1.3.x starts we should enable this
-// btw. we should also test this with 1.2 so that we
-// do not get any surprises. (Lgb)
-//#define NO_COMPABILITY 1
 
 ///
 struct DEPCLEAN {
@@ -108,7 +109,7 @@ public:
 	    \param par if != 0 insert the file.
 	    \return \c false if method fails.
 	*/
-	bool readFile(LyXLex &, Paragraph * par = 0);
+	bool readFile(LyXLex &, string const &, Paragraph * par = 0);
 
 	/** Reads a file without header.
 	    \param par if != 0 insert the file.
@@ -125,13 +126,6 @@ public:
 	///
 	void insertStringAsLines(Paragraph *&, lyx::pos_type &,
 				 LyXFont const &, string const &) const;
-#ifndef NO_COMPABILITY
-	///
-	Inset * isErtInset(Paragraph * par, int pos) const;
-	///
-	void insertErtContents(Paragraph * par, int & pos,
-			       bool set_inactive = true);
-#endif
 	///
 	Paragraph * getParFromID(int id) const;
 private:
@@ -145,19 +139,27 @@ public:
 	bool save() const;
 
 	/// Write file. Returns \c false if unsuccesful.
-	bool writeFile(string const &, bool) const;
+	bool writeFile(string const &) const;
 
 	///
 	void writeFileAscii(string const & , int);
 	///
 	void writeFileAscii(std::ostream &, int);
 	///
-	string const asciiParagraph(Paragraph const *, unsigned int linelen,
+	string const asciiParagraph(Paragraph const &, unsigned int linelen,
 				    bool noparbreak = false) const;
-	///
+	/// Just a wrapper for the method below, first creating the ofstream.
 	void makeLaTeXFile(string const & filename,
 			   string const & original_path,
-			   bool nice, bool only_body = false);
+			   bool nice,
+			   bool only_body = false,
+			   bool only_preamble = false);
+	///
+	void makeLaTeXFile(std::ostream & os,
+			   string const & original_path,
+			   bool nice,
+			   bool only_body = false,
+			   bool only_preamble = false);
 	/** LaTeX all paragraphs from par to endpar.
 	    \param \a endpar if == 0 then to the end
 	*/
@@ -176,12 +178,6 @@ public:
 	///
 	void makeDocBookFile(string const & filename,
 			     bool nice, bool only_body = false);
-	/// Open SGML/XML tag.
-	void sgmlOpenTag(std::ostream & os, Paragraph::depth_type depth,
-		string const & latexname) const;
-	/// Closes SGML/XML tag.
-	void sgmlCloseTag(std::ostream & os, Paragraph::depth_type depth,
-		string const & latexname) const;
 	///
 	void sgmlError(Paragraph * par, int pos, string const & message) const;
 
@@ -189,15 +185,15 @@ public:
 	Language const * getLanguage() const;
 	///
 	int runChktex();
-	///
-	bool isLyxClean() const;
+	/// return true if the main lyx file does not need saving
+	bool isClean() const;
 	///
 	bool isBakClean() const;
 	///
 	bool isDepClean(string const & name) const;
 
-	///
-	void markLyxClean() const;
+	/// mark the main lyx file as not needing saving
+	void markClean() const;
 
 	///
 	void markBakClean();
@@ -264,29 +260,10 @@ public:
 	*/
 	void validate(LaTeXFeatures &) const;
 
-	///
-	string const getIncludeonlyList(char delim = ',');
 	///
 	std::vector<std::pair<string, string> > const getBibkeyList() const;
 	///
-	struct TocItem {
-		TocItem(Paragraph * p, int d, string const & s)
-			: par(p), depth(d), str(s) {}
-		///
-		Paragraph * par;
-		///
-		int depth;
-		///
-		string str;
-	};
-	///
-	typedef std::vector<TocItem> SingleList;
-	///
-	typedef std::map<string, SingleList> Lists;
-	///
-	Lists const getLists() const;
-	///
-	std::vector<string> const getLabelList();
+	std::vector<string> const getLabelList() const;
 
 	/** This will clearly have to change later. Later we can have more
 	    than one user per buffer. */
@@ -298,10 +275,10 @@ public:
 	bool isMultiLingual();
 
 	/// Does this mean that this is buffer local?
-	UndoStack undostack;
+	limited_stack<boost::shared_ptr<Undo> > undostack;
 
 	/// Does this mean that this is buffer local?
-	UndoStack redostack;
+	limited_stack<boost::shared_ptr<Undo> > redostack;
 
 	///
 	BufferParams params;
@@ -310,7 +287,7 @@ public:
 	    This is a linked list of paragraph, this list holds the
 	    whole contents of the document.
 	 */
-	Paragraph * paragraph;
+	ParagraphList paragraphs;
 
 	/// LyX version control object.
 	LyXVC lyxvc;
@@ -357,7 +334,6 @@ private:
 	    of the buffers in the list of users to do a #updateLayoutChoice#.
 	*/
 	BufferView * users;
-
 public:
 	///
 	class inset_iterator {
@@ -367,46 +343,28 @@ public:
 		typedef ptrdiff_t difference_type;
 		typedef Inset * pointer;
 		typedef Inset & reference;
-
+		typedef ParagraphList::iterator base_type;
 
 		///
-		inset_iterator() : par(0) /*, it(0)*/ {}
-		//
-		inset_iterator(Paragraph * paragraph) : par(paragraph) {
-			setParagraph();
-		}
+		inset_iterator();
 		///
-		inset_iterator(Paragraph * paragraph, lyx::pos_type pos);
+		inset_iterator(base_type p, base_type e);
 		///
-		inset_iterator & operator++() { // prefix ++
-			if (par) {
-				++it;
-				if (it == par->inset_iterator_end()) {
-					par = par->next();
-					setParagraph();
-				}
-			}
-			return *this;
-		}
+		inset_iterator(base_type p, lyx::pos_type pos, base_type e);
+
+		/// prefix ++
+		inset_iterator & operator++();
+		/// postfix ++
+		inset_iterator operator++(int);
 		///
-		inset_iterator operator++(int) { // postfix ++
-			inset_iterator tmp(par, it.getPos());
-			if (par) {
-				++it;
-				if (it == par->inset_iterator_end()) {
-					par = par->next();
-					setParagraph();
-				}
-			}
-			return tmp;
-		}
+		reference operator*();
 		///
-		Inset * operator*() { return *it; }
+		pointer operator->();
 
 		///
-		Paragraph * getPar() { return par; }
+		Paragraph * getPar();
 		///
-		lyx::pos_type getPos() const { return it.getPos(); }
+		lyx::pos_type getPos() const;
 		///
 		friend
 		bool operator==(inset_iterator const & iter1,
@@ -415,23 +373,28 @@ public:
 		///
 		void setParagraph();
 		///
-		Paragraph * par;
+		ParagraphList::iterator pit;
 		///
-		Paragraph::inset_iterator it;
+		ParagraphList::iterator pend;
+		///
+		InsetList::iterator it;
 	};
 
 	///
 	inset_iterator inset_iterator_begin() {
-		return inset_iterator(paragraph);
+		return inset_iterator(paragraphs.begin(), paragraphs.end());
 	}
+
 	///
 	inset_iterator inset_iterator_end() {
 		return inset_iterator();
 	}
+
 	///
 	inset_iterator inset_const_iterator_begin() const {
-		return inset_iterator(paragraph);
+		return inset_iterator(paragraphs.begin(), paragraphs.end());
 	}
+
 	///
 	inset_iterator inset_const_iterator_end() const {
 		return inset_iterator();
@@ -440,167 +403,19 @@ public:
 	///
 	ParIterator par_iterator_begin();
 	///
+	ParConstIterator par_iterator_begin() const;
+	///
 	ParIterator par_iterator_end();
+	///
+	ParConstIterator par_iterator_end() const;
 
 	///
 	Inset * getInsetFromID(int id_arg) const;
 };
 
-
-inline
-void Buffer::addUser(BufferView * u)
-{
-	users = u;
-}
-
-
-inline
-void Buffer::delUser(BufferView *)
-{
-	users = 0;
-}
-
-
-inline
-Language const * Buffer::getLanguage() const
-{
-	return params.language;
-}
-
-
-inline
-bool Buffer::isLyxClean() const
-{
-	return lyx_clean;
-}
-
-
-inline
-bool Buffer::isBakClean() const
-{
-	return bak_clean;
-}
-
-
-inline
-void Buffer::markLyxClean() const
-{
-	if (!lyx_clean) {
-		lyx_clean = true;
-		updateTitles();
-	}
-	// if the .lyx file has been saved, we don't need an
-	// autosave
-	bak_clean = true;
-}
-
-
-inline
-void Buffer::markBakClean()
-{
-	bak_clean = true;
-}
-
-
-inline
-void Buffer::setUnnamed(bool flag)
-{
-	unnamed = flag;
-}
-
-
-inline
-bool Buffer::isUnnamed()
-{
-	return unnamed;
-}
-
-
-inline
-void Buffer::markDirty()
-{
-	if (lyx_clean) {
-		lyx_clean = false;
-		updateTitles();
-	}
-	bak_clean = false;
-	DEPCLEAN * tmp = dep_clean;
-	while (tmp) {
-		tmp->clean = false;
-		tmp = tmp->next;
-	}
-}
-
-
-inline
-string const & Buffer::fileName() const
-{
-	return filename_;
-}
-
-
-inline
-string const & Buffer::filePath() const
-{
-	return filepath_;
-}
-
-
-inline
-bool Buffer::isReadonly() const
-{
-	return read_only;
-}
-
-
-inline
-BufferView * Buffer::getUser() const
-{
-	return users;
-}
-
-
-inline
-void Buffer::setParentName(string const & name)
-{
-	params.parentname = name;
-}
-
-
-///
-inline
-bool operator==(Buffer::TocItem const & a, Buffer::TocItem const & b)
-{
-	return a.par == b.par && a.str == b.str;
-	// No need to compare depth.
-}
-
-
-///
-inline
-bool operator!=(Buffer::TocItem const & a, Buffer::TocItem const & b)
-{
-	return !(a == b);
-	// No need to compare depth.
-}
-
-
-///
-inline
 bool operator==(Buffer::inset_iterator const & iter1,
-		Buffer::inset_iterator const & iter2)
-{
-	return iter1.par == iter2.par
-		&& (iter1.par == 0 || iter1.it == iter2.it);
-}
+		Buffer::inset_iterator const & iter2);
 
-
-///
-inline
 bool operator!=(Buffer::inset_iterator const & iter1,
-		Buffer::inset_iterator const & iter2)
-{
-	return !(iter1 == iter2);
-}
-
+		Buffer::inset_iterator const & iter2);
 #endif
