@@ -1,15 +1,13 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file Menubar.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
- *           Copyright 1995 Matthias Ettrich
- *           Copyright 1995-2001 The LyX Team.
+ * \author Lars Gullik Bjnnes
  *
- *           This file is Copyright 1996-2001
- *           Lars Gullik Bjnnes
- *
- * ====================================================== */
+ * Full author contact details are available in file CREDITS
+ */
 
 #ifndef MENUBAR_H
 #define MENUBAR_H
@@ -23,17 +21,16 @@
 class LyXView;
 class MenuBackend;
 
-/** The LyX GUI independent menubar class
-  The GUI interface is implemented in the corresponding Menubar_pimpl class.
-  */
+/**
+ * The LyX GUI independent menubar class
+ * The GUI interface is implemented in the corresponding Menubar_pimpl class.
+ */
 class Menubar {
 public:
 	///
 	Menubar(LyXView * o, MenuBackend const &);
 	///
 	~Menubar();
-	///
-	void set(string const &);
 	/// Opens a top-level submenu given its name
 	void openByName(string const &);
 	/// update the state of the menuitems
@@ -49,4 +46,4 @@ private:
 	///
 	Pimpl * pimpl_;
 };
-#endif
+#endif // MENUBAR_H
