@@ -1,11 +1,13 @@
 // -*- C++ -*-
 /**
  * \file ControlAboutlyx.h
- * Copyright 2001 The LyX Team.
- * See the file COPYING.
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven, leuven@fee.uva.nl
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Edwin Leuven
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLABOUTLYX_H
@@ -16,9 +18,10 @@
 #endif
 
 #include "ControlDialog_impl.h"
-#include "Lsstream.h"
 #include "LString.h"
 
+#include <iosfwd>
+
 /** A controller for the About LyX dialogs.
  */
 class ControlAboutlyx : public ControlDialogBI {
@@ -27,7 +30,7 @@ public:
 	ControlAboutlyx(LyXView &, Dialogs &);
 
 	///
-	stringstream & getCredits(stringstream &) const;
+	void getCredits(std::ostream &) const;
 
 	///
 	string const getCopyright() const;
@@ -40,8 +43,6 @@ public:
 
 	///
 	string const getVersion() const;
-
-
 private:
 	/// not needed.
 	virtual void apply() {}
