@@ -1,15 +1,12 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *           Copyright 2001 The LyX Team.
- *
- * ======================================================
- *
+/**
  * \file ControlCitation.h
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLCITATION_H
@@ -24,8 +21,7 @@
 
 /** A controller for Citation dialogs.
  */
-class ControlCitation : public ControlCommand
-{
+class ControlCitation : public ControlCommand {
 public:
 	///
 	ControlCitation(LyXView &, Dialogs &);
@@ -39,9 +35,9 @@ public:
 	std::vector<string> const getCiteStrings(string const & key) const;
 
 	/// available CiteStyle-s (depends on availability of Natbib
-	static std::vector<biblio::CiteStyle> const & getCiteStyles()
-		{ return citeStyles_; }
-
+	static std::vector<biblio::CiteStyle> const & getCiteStyles() {
+		return citeStyles_;
+	}
 private:
 	/// create the InfoMap of keys and data
 	virtual void setDaughterParams();
