@@ -1,10 +1,12 @@
 // -*- C++ -*-
-/*
+/**
  * \file ControlDialog.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  *
  * ControlDialog is to be used as a parent class for dialogs that are not
  * views onto parameters of insets. (An ugly description I know, but I hope
@@ -23,31 +25,28 @@ class Dialogs;
     The Base class will be either ControlConnectBI or ControlConnectBD.
  */
 template <class Base>
-class ControlDialog : public Base
-{
+class ControlDialog : public Base {
 public:
 	///
 	ControlDialog(LyXView &, Dialogs &);
 
-protected:
-	/// Show the dialog.
+	/** Show the dialog.
+	 *  Publicly accessible so that it can be invoked by the Dialogs class.
+	 */
 	virtual void show();
 	/// Hide the dialog.
 	virtual void hide();
 	/// Update the dialog.
 	virtual void update();
 
+protected:
 	/// clean-up on hide.
 	virtual void clearParams() {}
 	/// set the params before show or update
 	virtual void setParams() {}
-
 private:
 	/// is the dialog built ?
 	bool dialog_built_;
 };
 
-
-#include "ControlDialog.tmpl"
-
 #endif // CONTROLDIALOG_H
