@@ -1,10 +1,12 @@
 // -*- C++ -*-
-/*
+/**
  * \file ControlDialog_impl.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  *
  * Instatiate the two possible instantiations of the ControlDialog template
  * class, thus reducing file dependencies enormously.
@@ -20,16 +22,14 @@ class Dialogs;
 class LyXView;
 
 
-class ControlDialogBD : public ControlDialog<ControlConnectBD>
-{
+class ControlDialogBD : public ControlDialog<ControlConnectBD> {
 public:
 	///
 	ControlDialogBD(LyXView &, Dialogs &);
 };
 
 
-class ControlDialogBI : public ControlDialog<ControlConnectBI>
-{
+class ControlDialogBI : public ControlDialog<ControlConnectBI> {
 public:
 	///
 	ControlDialogBI(LyXView &, Dialogs &);
