@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file ControlForks.h
- * Copyright 2001 The LyX Team
- * Read COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLFORKS_H
@@ -16,6 +18,9 @@
 
 #include "ControlDialog_impl.h"
 #include "LString.h"
+
+#include <boost/signals/connection.hpp>
+
 #include <sys/types.h>
 #include <vector>
 
@@ -32,7 +37,6 @@ public:
 	string const getCommand(pid_t) const;
 	///
 	void kill(pid_t);
-
 private:
 	///
 	virtual void apply();
@@ -41,7 +45,7 @@ private:
 	/// connect to the ForkedcallsController
 	virtual void setParams();
 	/// Connection to the ForkedcallsController signal
-	SigC::Connection childrenChanged_;
+	boost::signals::connection childrenChanged_;
 	/// The list of PIDs to kill
 	std::vector<string> pids_;
 };
