@@ -1,15 +1,12 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file ControlInset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Angus Leeming
  *
- *           Copyright 2001 The LyX Team.
- *
- * ======================================================
- *
- * \file ControlInsets.h
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * Full author contact details are available in file CREDITS
  *
  * ControlInset is to be used as a parent class for dialogs that display and
  * can perhaps modify the contents of an individual inset. An example being the
@@ -22,11 +19,12 @@
 #include "ControlConnections.h"
 #include "LString.h"
 
+#include <boost/signals/connection.hpp>
+
 class Inset;
 
 template <class Inset, class Params>
-class ControlInset : public ControlConnectBD
-{
+class ControlInset : public ControlConnectBD {
 public:
 	///
 	ControlInset(LyXView &, Dialogs &);
@@ -35,15 +33,14 @@ public:
 	///
 	Params const & params() const;
 
-protected:
 	/// Slots connected in the daughter classes c-tor.
 	/// Slot launching dialog to (possibly) create a new inset.
 	void createInset(string const &);
 	/// Slot launching dialog to an existing inset.
 	void showInset(Inset *);
+protected:
 	/// Allow the daughter methods to access the inset.
 	Inset * inset() const;
-
 private:
 	/** These 7 methods are all that the individual daughter classes
 	    should need to instantiate. */
@@ -71,8 +68,6 @@ private:
 	 dialog allows multiple citiations to be inserted easily. */
 	virtual bool disconnectOnApply() { return false; }
 
-
-
 	/// Instantiation of ControlButtons virtual methods.
 
 	/// Get changed parameters and Dispatch them to the kernel.
@@ -94,7 +89,7 @@ private:
 	/// pointer to the inset passed through connectInset
 	Inset * inset_;
 	/// inset::hide connection.
-	SigC::Connection ih_;
+	boost::signals::connection ih_;
 	/** A local copy of the inset's params.
 	    Memory is allocated only whilst the dialog is visible.
 	*/
@@ -102,11 +97,8 @@ private:
 
 	/// is the dialog built ?
 	bool dialog_built_;
-
 };
 
-
-
 #include "ControlInset.tmpl"
 
 #endif // CONTROLINSET_H
