@@ -1,16 +1,13 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *           Copyright 2001 The LyX Team.
- *
- * ======================================================
- *
+/**
  * \file ControlLog.h
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLLOG_H
@@ -33,9 +30,9 @@ public:
 	///
 	ControlLog(LyXView &, Dialogs &);
 	///
-	std::pair<Buffer::LogType, string> const & logfile()
-		{ return logfile_; }
-
+	std::pair<Buffer::LogType, string> const & logfile() {
+		return logfile_;
+	}
 private:
 	///
 	virtual void apply() {}
