@@ -1,15 +1,13 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *          Copyright 2001 The LyX Team.
- *
- *======================================================
- *
+/**
  * \file ControlPrint.h
- * \author Angus Leeming, a.leeming@.ac.uk
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Allan Rae
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLPRINT_H
@@ -21,6 +19,8 @@
 
 #include "ControlDialog_impl.h"
 
+#include "LString.h"
+
 class PrinterParams;
 
 /** A controller for Print dialogs.
@@ -34,7 +34,6 @@ public:
 	string const Browse(string const &);
 	///
 	PrinterParams & params() const;
-
 private:
 	/// Get changed parameters and Dispatch them to the kernel.
 	virtual void apply();
