@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file ControlSendto.h
- * Copyright 2002 The LyX Team.
- * See the file COPYING.
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLSENDTO_H
@@ -15,6 +17,8 @@
 #endif
 
 #include "ControlDialog_impl.h"
+#include "LString.h"
+
 #include <vector>
 
 class Format;
@@ -36,7 +40,6 @@ public:
 	/// The command to be executed
 	string const getCommand() const { return command_; };
 	void setCommand(string const &);
-
 private:
 	///
 	virtual void apply();
