@@ -1,16 +1,13 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *           Copyright 2001 The LyX Team.
- *
- * ======================================================
- *
+/**
  * \file ControlVCLog.h
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLVCLOG_H
@@ -21,7 +18,8 @@
 #endif
 
 #include "ControlDialog_impl.h"
-#include "Lsstream.h"
+
+#include "LString.h"
 
 /**
  * A controller for the Version Control log viewer.
@@ -30,11 +28,10 @@ class ControlVCLog : public ControlDialogBD {
 public:
 	///
 	ControlVCLog(LyXView &, Dialogs &);
-	/// get a stringstream containing the log file
-	stringstream & getVCLogFile(stringstream & ss) const;
+	/// put the log file into the ostream
+	void getVCLogFile(std::ostream & ss) const;
 	/// get the filename of the buffer
 	string const getBufferFileName() const;
-
 private:
 	///
 	virtual void apply() {}
