@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file gnome/Timeout_pimpl.h
- * Copyright 2001 LyX Team
- * Read COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Baruch Even
+ *
+ * Full author contact details are available in file CREDITS
  */
 #ifndef TIMEOUTPIMPL_H
 #define TIMEOUTPIMPL_H
@@ -12,7 +14,7 @@
 #include "frontends/Timeout.h"
 #include "glib.h" // for gint
 
-#include <sigc++/signal_system.h>
+#include <sigc++/sigc++.h>
 
 #ifdef __GNUG__
 #pragma interface
@@ -38,7 +40,7 @@ public:
 
 public:
 	/// The timeout signal, this gets called when the timeout passed.
-	gint timeoutEvent();
+	bool timeoutEvent();
 private:
 	/// the owning timer
 	Timeout * owner_;
