@@ -1,31 +1,35 @@
 // -*- C++ -*-
 /**
  * \file QBibitem.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QBIBITEM_H
 #define QBIBITEM_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "Qt2Base.h"
 
 class ControlBibitem;
 class QBibitemDialog;
 
-class QBibitem :
-	public Qt2CB<ControlBibitem, Qt2DB<QBibitemDialog> >
+class QBibitem
+	: public Qt2CB<ControlBibitem, Qt2DB<QBibitemDialog> >
 {
+public:
 	friend class QBibitemDialog;
 
-public:
-	QBibitem(ControlBibitem &);
-
+	QBibitem();
 protected:
 	virtual bool isValid();
-
 private:
 	/// Apply changes
 	virtual void apply();
