@@ -1,31 +1,35 @@
 // -*- C++ -*-
 /**
  * \file QBibtex.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QBIBTEX_H
 #define QBIBTEX_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "Qt2Base.h"
 
 class ControlBibtex;
 class QBibtexDialog;
 
-class QBibtex :
-	public Qt2CB<ControlBibtex, Qt2DB<QBibtexDialog> >
+class QBibtex
+	: public Qt2CB<ControlBibtex, Qt2DB<QBibtexDialog> >
 {
+public:
 	friend class QBibtexDialog;
 
-public:
-	QBibtex(ControlBibtex &);
-
+	QBibtex();
 protected:
 	virtual bool isValid();
-
 private:
 	/// Apply changes
 	virtual void apply();
