@@ -1,36 +1,42 @@
 // -*- C++ -*-
 /**
  * \file QCharacter.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven, leuven@fee.uva.nl
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author Edwin Leuven
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QCHARACTER_H
 #define QCHARACTER_H
 
-#include <config.h>
-#include <vector>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
-#include "LString.h"
 #include "Qt2Base.h"
 #include "controllers/character.h"
 #include "controllers/frnt_lang.h"
 
+#include "LString.h"
+
+#include <vector>
+
 
 class ControlCharacter;
 class QCharacterDialog;
 
-class QCharacter :
-	public Qt2CB<ControlCharacter, Qt2DB<QCharacterDialog> >
+
+class QCharacter
+	: public Qt2CB<ControlCharacter, Qt2DB<QCharacterDialog> >
 {
+public:
 	friend class QCharacterDialog;
 
-public:
-	QCharacter(ControlCharacter &);
-
+	QCharacter();
 private:
 	/// Apply changes
 	virtual void apply();
