@@ -1,19 +1,24 @@
+// -*- C++ -*-
 /**
  * \file QCharacterDialog.h
- * Copyright 2001 the LyX Team
- * see the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Edwin Leuven
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QCHARACTERDIALOG_H
 #define QCHARACTERDIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
-#include "ui/QCharacterDialogBase.h"
 #include "QCharacter.h"
+#include "ui/QCharacterDialogBase.h"
 
 #include <qevent.h>
 #include <qcheckbox.h>
@@ -21,18 +26,14 @@
 
 class LyXFont;
 
-class QCharacterDialog : public QCharacterDialogBase
-{ Q_OBJECT
-
+class QCharacterDialog : public QCharacterDialogBase {
+	Q_OBJECT
 public:
 	QCharacterDialog(QCharacter * form);
-
 protected:
 	void closeEvent(QCloseEvent * e);
-
 private:
 	QCharacter * form_;
-
 protected slots:
 	void change_adaptor();
 };
