@@ -1,11 +1,13 @@
 // -*- C++ -*-
 /**
  * \file QCitation.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming <a.leeming@ic.ac.uk>
- * \author Kalle Dalheimer <kalle@klaralvdalens-datakonsult.se>
+ * \author Angus Leeming
+ * \author Kalle Dalheimer
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QCITATION_H
@@ -15,21 +17,20 @@
 #pragma interface
 #endif
 
-class QListBox;
-
 #include "Qt2Base.h"
 
+class QListBox;
 class ControlCitation;
 class QCitationDialog;
 
-class QCitation : public Qt2CB<ControlCitation, Qt2DB<QCitationDialog> >
+
+class QCitation
+	: public Qt2CB<ControlCitation, Qt2DB<QCitationDialog> >
 {
-	friend class QCitationDialog;
-
 public:
+	friend class QCitationDialog;
 	///
-	QCitation(ControlCitation &);
-
+	QCitation();
 private:
 	///
 	enum State {
