@@ -1,28 +1,33 @@
 // -*- C++ -*-
 /**
  * \file QERT.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QERT_H
 #define QERT_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "Qt2Base.h"
 
 class ControlERT;
 class QERTDialog;
 
-class QERT :
-	public Qt2CB<ControlERT, Qt2DB<QERTDialog> >
+class QERT
+	: public Qt2CB<ControlERT, Qt2DB<QERTDialog> >
 {
+public:
 	friend class QERTDialog;
 
-public:
-	QERT(ControlERT &);
-
+	QERT();
 private:
 	/// Apply changes
 	virtual void apply();
