@@ -1,30 +1,33 @@
 // -*- C++ -*-
 /**
  * \file QExternal.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QEXTERNAL_H
 #define QEXTERNAL_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "Qt2Base.h"
 
 class ControlExternal;
 class QExternalDialog;
 
-class QExternal :
-	public Qt2CB<ControlExternal, Qt2DB<QExternalDialog> >
+class QExternal
+	: public Qt2CB<ControlExternal, Qt2DB<QExternalDialog> >
 {
+public:
 	friend class QExternalDialog;
 
-public:
-	QExternal(ControlExternal &);
-
-protected:
-	virtual bool isValid();
+	QExternal();
 
 private:
 	/// Apply changes
