@@ -1,26 +1,31 @@
+// -*- C++ -*-
 /**
  * \file QExternalDialog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QEXTERNALDIALOG_H
 #define QEXTERNALDIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "ui/QExternalDialogBase.h"
 
 class QExternal;
 
-class QExternalDialog : public QExternalDialogBase
-{ Q_OBJECT
-
+class QExternalDialog : public QExternalDialogBase {
+	Q_OBJECT
 public:
 	QExternalDialog(QExternal * form);
 
+	virtual void show();
 protected slots:
 	virtual void change_adaptor();
 	virtual void editClicked();
@@ -28,10 +33,8 @@ protected slots:
 	virtual void updateClicked();
 	virtual void browseClicked();
 	virtual void templateChanged();
-
 protected:
 	virtual void closeEvent(QCloseEvent * e);
-
 private:
 	QExternal * form_;
 };
