@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file QFloat.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven <leuven@fee.uva.nl>
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QFLOAT_H
@@ -27,7 +29,7 @@ public:
 	///
 	friend class QFloatDialog;
 	///
-	QFloat(ControlFloat &);
+	QFloat();
 private:
 	/// Apply changes
 	virtual void apply();
