@@ -1,10 +1,13 @@
 // -*- C++ -*-
 /**
  * \file QGraphics.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ * \author Herbert Voss
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QGRAPHICS_H
@@ -14,8 +17,8 @@
 #pragma interface
 #endif
 
-#include "Qt2Base.h"
 #include "insets/insetgraphics.h"
+#include "Qt2Base.h"
 
 class ControlGraphics;
 class QGraphicsDialog;
@@ -28,11 +31,9 @@ public:
 	///
 	friend class QGraphicsDialog;
 	///
-	QGraphics(ControlGraphics &);
-
+	QGraphics();
 protected:
 	virtual bool isValid();
-
 private:
 	/// Apply changes
 	virtual void apply();
@@ -40,11 +41,12 @@ private:
 	virtual void update_contents();
 	/// build the dialog
 	virtual void build_dialog();
-
-	/// browse for a file
-	void browse();
 	/// get bounding box from file
-	void get();
+	void getBB();
+
+	/// Store the LaTeX names for the rotation origins.
+	std::vector<string> origin_ltx;
+
 };
 
 #endif // QGRAPHICS_H
