@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file QInclude.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QINCLUDE_H
@@ -27,11 +29,9 @@ public:
 	///
 	friend class QIncludeDialog;
 	///
-	QInclude(ControlInclude &);
-
+	QInclude();
 protected:
 	virtual bool isValid();
-
 private:
 	/// Apply changes
 	virtual void apply();
