@@ -1,37 +1,40 @@
+// -*- C++ -*-
 /**
  * \file QIncludeDialog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QINCLUDEDIALOG_H
 #define QINCLUDEDIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "ui/QIncludeDialogBase.h"
 
 class QInclude;
 
-class QIncludeDialog : public QIncludeDialogBase
-{ Q_OBJECT
-
+class QIncludeDialog : public QIncludeDialogBase {
+	Q_OBJECT
 public:
 	QIncludeDialog(QInclude * form);
 
 	void updateLists();
 
+	virtual void show();
 protected slots:
 	virtual void change_adaptor();
 	virtual void loadClicked();
 	virtual void browseClicked();
 	virtual void typeChanged(int v);
-
 protected:
 	virtual void closeEvent(QCloseEvent * e);
-
 private:
 	QInclude * form_;
 };
