@@ -1,32 +1,37 @@
 // -*- C++ -*-
 /**
  * \file QIndex.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
- * \author Kalle Dalheimer <kalle@klaralvdalens-datakonsult.se>
+ * \author John Levon
+ * \author Kalle Dalheimer
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QINDEX_H
 #define QINDEX_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "Qt2Base.h"
 
 class ControlIndex;
 class QIndexDialog;
 
+
 class QIndex :
 	public Qt2CB<ControlIndex, Qt2DB<QIndexDialog> >
 {
+public:
 	friend class QIndexDialog;
 
-public:
-	QIndex(ControlIndex &);
-
+	QIndex();
 protected:
 	virtual bool isValid();
-
 private:
 	/// Apply changes
 	virtual void apply();
