@@ -1,29 +1,31 @@
+// -*- C++ -*-
 /**
  * \file QShowFileDialog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QSHOWFILEDIALOG_H
 #define QSHOWFILEDIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "ui/QShowFileDialogBase.h"
 
 class QShowFile;
 
-class QShowFileDialog : public QShowFileDialogBase
-{ Q_OBJECT
-
+class QShowFileDialog : public QShowFileDialogBase {
+	Q_OBJECT
 public:
 	QShowFileDialog(QShowFile * form);
-
 protected:
 	virtual void closeEvent(QCloseEvent * e);
-
 private:
 	QShowFile * form_;
 };
