@@ -1,46 +1,48 @@
 // -*- C++ -*-
 /**
  * \file QSpellchecker.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
- * \author Kalle Dalheimer <kalle@klaralvdalens-datakonsult.se>
+ * \author John Levon
+ * \author Kalle Dalheimer
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QSPELLCHECKER_H
 #define QSPELLCHECKER_H
 
-#include "Qt2Base.h"
+#ifdef __GNUG__
+#pragma interface
+#endif
 
+#include "Qt2Base.h"
 
 class ControlSpellchecker;
 class QSpellcheckerDialog;
 
-class QSpellchecker :
-	public Qt2CB<ControlSpellchecker, Qt2DB<QSpellcheckerDialog> >
+
+class QSpellchecker
+	: public Qt2CB<ControlSpellchecker, Qt2DB<QSpellcheckerDialog> >
 {
+public:
 	friend class QSpellcheckerDialog;
 
-public:
-	QSpellchecker(ControlSpellchecker &);
+	QSpellchecker();
 
 	/// update from controller
 	void partialUpdate(int id);
-
 private:
-	void stop();
 	void accept();
 	void add();
 	void ignore();
 	void replace();
-	void options();
-	void spellcheck();
 
 	/// Apply changes
-	virtual void apply() {};
-	/// update
-	virtual void update_contents();
+	virtual void apply() {}
+	/// not needed
+	virtual void update_contents() {}
 	/// build the dialog
 	virtual void build_dialog();
 };
