@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file QTabularCreate.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTABULARCREATE_H
@@ -19,6 +21,7 @@
 class ControlTabularCreate;
 class QTabularCreateDialog;
 
+
 ///
 class QTabularCreate
 	: public Qt2CB<ControlTabularCreate, Qt2DB<QTabularCreateDialog> >
@@ -27,13 +30,12 @@ public:
 	///
 	friend class QTabularCreateDialog;
 	///
-	QTabularCreate(ControlTabularCreate &);
-
+	QTabularCreate();
 private:
 	/// Apply changes
 	virtual void apply();
 	/// update
-	virtual void update_contents() {};
+	virtual void update_contents() {}
 	/// build the dialog
 	virtual void build_dialog();
 };
