@@ -1,29 +1,33 @@
+// -*- C++ -*-
 /**
  * \file QTabularCreateDialog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
- * \author Edwin Leuven <leuven@fee.uva.nl>
+ * \author John Levon
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTABULARCREATEDIALOG_H
 #define QTABULARCREATEDIALOG_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "ui/QTabularCreateDialogBase.h"
 
 class QTabularCreate;
 
-class QTabularCreateDialog : public QTabularCreateDialogBase
-{ Q_OBJECT
-
+class QTabularCreateDialog : public QTabularCreateDialogBase {
+	Q_OBJECT
 public:
 	QTabularCreateDialog(QTabularCreate * form);
-
 protected slots:
 	virtual void columnsChanged(int);
 	virtual void rowsChanged(int);
-
 private:
 	QTabularCreate * form_;
 };
