@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file QTexinfo.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven <leuven@fee.uva.nl>
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTEXINFO_H
@@ -18,6 +20,8 @@
 
 #include "ControlTexinfo.h"
 
+#include <vector>
+
 class QTexinfoDialog;
 
 ///
@@ -28,12 +32,12 @@ public:
 	///
 	friend class QTexinfoDialog;
 	///
-	QTexinfo(ControlTexinfo &);
+	QTexinfo();
 private:
 	/// Apply changes
-	virtual void apply() { };
+	virtual void apply() {}
 	/// update (do we need this?)
-	virtual void update_contents() {};
+	virtual void update_contents() {}
 	/// build the dialog
 	virtual void build_dialog();
 	///
@@ -44,7 +48,12 @@ private:
 	bool warningPosted;
 	///
 	ControlTexinfo::texFileSuffix activeStyle;
-
+	///
+	std::vector<string> cls_;
+	///
+	std::vector<string> sty_;
+	///
+	std::vector<string> bst_;
 };
 
 #endif // QTEXINFO_H
