@@ -1,35 +1,37 @@
+// -*- C++ -*-
 /**
  * \file QTexinfoDialog.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven <leuven@fee.uva.nl>
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTEXINFODIALOG_H
 #define QTEXINFODIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "ui/QTexinfoDialogBase.h"
 
 class QTexinfo;
 
-class QTexinfoDialog : public QTexinfoDialogBase
-{ Q_OBJECT
-
+class QTexinfoDialog : public QTexinfoDialogBase {
+	Q_OBJECT
 public:
 	QTexinfoDialog(QTexinfo * form);
-
 protected slots:
 	virtual void change_adaptor();
 	virtual void rescanClicked();
 	virtual void viewClicked();
 	virtual void update();
-
+	virtual void enableViewPB();
 protected:
 	virtual void closeEvent(QCloseEvent * e);
-
 private:
 	QTexinfo * form_;
 };
