@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file QThesaurus.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTHESAURUS_H
@@ -27,10 +29,10 @@ public:
 	///
 	friend class QThesaurusDialog;
 	///
-	QThesaurus(ControlThesaurus &);
+	QThesaurus();
 private:
 	/// Apply changes
-	virtual void apply() { };
+	virtual void apply() {}
 	/// update
 	virtual void update_contents();
 	/// build the dialog
