@@ -1,11 +1,13 @@
 // -*- C++ -*-
 /**
  * \file QToc.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author John Levon
- * \author Kalle Dalheimer <kalle@klaralvdalens-datakonsult.se>
+ * \author Kalle Dalheimer
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QTOC_H
@@ -16,8 +18,7 @@
 #endif
 
 #include "Qt2Base.h"
-
-#include "ControlToc.h"
+#include "toc.h"
 
 class ControlToc;
 class QTocDialog;
@@ -26,10 +27,9 @@ class QToc :
 	public Qt2CB<ControlToc, Qt2DB<QTocDialog> >
 {
 public:
-	QToc(ControlToc &);
-
 	friend class QTocDialog;
 
+	QToc();
 private:
 	/// update the listview
 	void updateToc(int newdepth);
@@ -43,7 +43,7 @@ private:
 	/// set the depth
 	void set_depth(int depth);
 
-	virtual void apply() {};
+	virtual void apply() {}
 
 	/// update dialog
 	virtual void update_contents();
@@ -52,7 +52,7 @@ private:
 	virtual void build_dialog();
 
 	/// the toc list
-	Buffer::SingleList toclist;
+	toc::Toc toclist;
 
 	/// depth of list shown
 	int depth_;
