@@ -1,32 +1,33 @@
+// -*- C++ -*-
 /**
  * \file QVCLogDialog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QVCLOGDIALOG_H
 #define QVCLOGDIALOG_H
 
-#include <config.h>
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 #include "ui/QVCLogDialogBase.h"
 
 class QVCLog;
 
-class QVCLogDialog : public QVCLogDialogBase
-{ Q_OBJECT
-
+class QVCLogDialog : public QVCLogDialogBase {
+	Q_OBJECT
 public:
 	QVCLogDialog(QVCLog * form);
-
 protected slots:
 	virtual void updateClicked();
-
 protected:
 	virtual void closeEvent(QCloseEvent * e);
-
 private:
 	QVCLog * form_;
 };
