@@ -1,26 +1,24 @@
 // -*- C++ -*-
 /**
  * \file qt2/Timeout_pimpl.h
- * Copyright 2001 LyX Team
- * Read COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef TIMEOUTPIMPL_H
 #define TIMEOUTPIMPL_H
 
-#include <config.h>
-
 #ifdef __GNUG__
 #pragma interface
 #endif
 
 #include "frontends/Timeout.h"
-
-#include <sigc++/signal_system.h>
-
 #include <qobject.h>
+
 // stupid Qt
 #undef emit
 
@@ -40,14 +38,13 @@ public:
 	void reset();
 	/// is the timer running ?
 	bool running() const;
-
 protected:
 	/// slot
 	virtual void timerEvent(QTimerEvent *);
 private:
 	/// the owning timer
 	Timeout * owner_;
-	/// xforms id
+	/// QTimer id
 	int timeout_id;
 };
 
