@@ -1,11 +1,13 @@
 // -*- C++ -*-
 /**
  * \file FormBibitem.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMBIBITEM_H
@@ -18,16 +20,15 @@
 #include "FormBase.h"
 
 class ControlBibitem;
-struct FD_form_bibitem;
+struct FD_bibitem;
 
 /**
  * For bibliography entry editing
  */
-class FormBibitem : public FormCB<ControlBibitem, FormDB<FD_form_bibitem> > {
+class FormBibitem : public FormCB<ControlBibitem, FormDB<FD_bibitem> > {
 public:
 	///
-	FormBibitem(ControlBibitem &);
-
+	FormBibitem();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -37,9 +38,6 @@ private:
 	virtual void update();
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
-
-	/// Fdesign generated method
-	FD_form_bibitem * build_bibitem();
 };
 
 #endif // FORMBIBITEM_H
