@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormCitation.h
- * Copyright 2000-2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMCITATION_H
@@ -20,13 +22,12 @@
 /** This class provides an XForms implementation of the Citation Dialog.
  */
 class ControlCitation;
-struct FD_form_citation;
+struct FD_citation;
 
-class FormCitation : public FormCB<ControlCitation, FormDB<FD_form_citation> > {
+class FormCitation : public FormCB<ControlCitation, FormDB<FD_citation> > {
 public:
 	///
-	FormCitation(ControlCitation &);
-
+	FormCitation();
 private:
 	///
 	enum State {
@@ -47,9 +48,6 @@ private:
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 
-	/// Fdesign generated method
-	FD_form_citation * build_citation();
-
 	/// search for a citation
 	void findBiblio(biblio::Direction const dir);
 
