@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormERT.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Jrgen Vigna, jug@sad.it
+ * \author Jrgen Vigna
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMERT_H
@@ -17,16 +19,16 @@
 #include "FormBase.h"
 
 class ControlERT;
-struct FD_form_ert;
+struct FD_ert;
 
 /** This class provides an XForms implementation of the ERT
     Dialog.
  */
 class FormERT
-	: public FormCB<ControlERT, FormDB<FD_form_ert> > {
+	: public FormCB<ControlERT, FormDB<FD_ert> > {
 public:
 	///
-	FormERT(ControlERT &);
+	FormERT();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -34,9 +36,6 @@ private:
 	virtual void build();
 	/// Update dialog before/whilst showing it.
 	virtual void update();
-
-	/// Fdesign generated method
-	FD_form_ert * build_ert();
 };
 
 #endif // FORMERT_H
