@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormError.h
- * Copyright 2000-2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMERROR_H
@@ -17,15 +19,14 @@
 #include "FormBase.h"
 
 class ControlError;
-struct FD_form_error;
+struct FD_error;
 
 /** This class provides an XForms implementation of the Error Dialog.
  */
-class FormError : public FormCB<ControlError, FormDB<FD_form_error> > {
+class FormError : public FormCB<ControlError, FormDB<FD_error> > {
 public:
 	/// Constructor
-	FormError(ControlError &);
-
+	FormError();
 private:
 	/// not needed.
 	virtual void apply() {}
@@ -33,9 +34,6 @@ private:
 	virtual void build();
 	/// Update dialog before showing it
 	virtual void update();
-
-	/// Fdesign generated method
-	FD_form_error * build_error();
 };
 
 #endif // FORMERROR_H
