@@ -1,12 +1,14 @@
 // -*- C++ -*-
 /**
  * \file FormExternal.h
- * Copyright 2000-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Asger Alstrup Nielsen
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMEXTERNAL_H
@@ -20,32 +22,28 @@
 #include "insets/insetexternal.h"
 
 class ControlExternal;
-struct FD_form_external;
+struct FD_external;
 
 /// The class for editing External insets via a dialog
-class FormExternal : public FormCB<ControlExternal, FormDB<FD_form_external> > {
+class FormExternal : public FormCB<ControlExternal, FormDB<FD_external> > {
 public:
 	///
-	FormExternal(ControlExternal &);
-
+	FormExternal();
 private:
 	/// apply changes
-	void apply();
+	virtual void apply();
 
 	/// build the dialog
-	void build();
+	virtual void build();
 
 	/// update the dialog
-	void update();
+	virtual void update();
 
 	/// Filter the inputs on callback from xforms
-	ButtonPolicy::SMInput input(FL_OBJECT *, long);
+	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 
 	///
 	void updateComboChange();
-
-	/// Fdesign generated method
-	FD_form_external * build_external();
 };
 
 #endif // FORMEXTERNAL_H
