@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file FormFloat.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Lars Gullik Bjnnes, larsbj@lyx.org
+ * \author Lars Gullik Bjnnes
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMFLOAT_H
@@ -15,18 +17,18 @@
 #endif
 
 #include "FormBase.h"
+#include "RadioButtonGroup.h"
 
 class ControlFloat;
-struct FD_form_float;
+struct FD_float;
 
 /** This class provides an XForms implementation of the Float
     Dialog.
  */
-class FormFloat : public FormCB<ControlFloat, FormDB<FD_form_float> > {
+class FormFloat : public FormCB<ControlFloat, FormDB<FD_float> > {
 public:
 	///
-	FormFloat(ControlFloat &);
-
+	FormFloat();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -37,8 +39,8 @@ private:
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 
-	/// Fdesign generated method
-	FD_form_float * build_float();
+	/// placement
+	RadioButtonGroup placement_;
 };
 
 #endif // FORMFLOAT_H
