@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormIndex.h
- * Copyright 2000-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMINDEX_H
@@ -17,15 +19,14 @@
 #include "FormBase.h"
 
 class ControlIndex;
-struct FD_form_index;
+struct FD_index;
 
 /** This class provides an XForms implementation of the Index Dialog.
  */
-class FormIndex : public FormCB<ControlIndex, FormDB<FD_form_index> > {
+class FormIndex : public FormCB<ControlIndex, FormDB<FD_index> > {
 public:
 	///
-	FormIndex(ControlIndex &);
-
+	FormIndex();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -33,9 +34,6 @@ private:
 	virtual void build();
 	/// Update dialog before/whilst showing it.
 	virtual void update();
-
-	/// Fdesign generated method
-	FD_form_index * build_index();
 };
 
 #endif // FORMINDEX_H
