@@ -1,10 +1,12 @@
 // -*- C++ -*-
-/*
+/**
  * FormLog.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon, moz@compsoc.man.ac.uk
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMLOG_H
@@ -25,7 +27,7 @@ class ControlLog;
 class FormLog : public FormCB<ControlLog, FormBrowser> {
 public:
 	///
-	FormLog(ControlLog &);
+	FormLog();
 
 	// Functions accessible to the Controller.
 
