@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file FormMinipage.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Jrgen Vigna, jug@sad.it
+ * \author Jrgen Vigna
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMMINIPAGE_H
@@ -17,16 +19,16 @@
 #include "FormBase.h"
 
 class ControlMinipage;
-struct FD_form_minipage;
+struct FD_minipage;
 
 /** This class provides an XForms implementation of the Minipage
     Dialog.
  */
 class FormMinipage
-	: public FormCB<ControlMinipage, FormDB<FD_form_minipage> > {
+	: public FormCB<ControlMinipage, FormDB<FD_minipage> > {
 public:
 	///
-	FormMinipage(ControlMinipage &);
+	FormMinipage();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -36,9 +38,6 @@ private:
 	virtual void update();
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
-
-	/// Fdesign generated method
-	FD_form_minipage * build_minipage();
 };
 
 #endif // FORMMINIPAGE_H
