@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormRef.h
- * Copyright 2000-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMREF_H
@@ -17,15 +19,14 @@
 #include "FormBase.h"
 
 class ControlRef;
-struct FD_form_ref;
+struct FD_ref;
 
 /** This class provides an XForms implementation of the FormRef Dialog.
  */
-class FormRef : public FormCB<ControlRef, FormDB<FD_form_ref> > {
+class FormRef : public FormCB<ControlRef, FormDB<FD_ref> > {
 public:
 	///
-	FormRef(ControlRef &);
-
+	FormRef();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -39,8 +40,8 @@ private:
 	///
 	void updateBrowser(std::vector<string> const &) const;
 
-	/// Fdesign generated method
-	FD_form_ref * build_ref();
+	///
+	void switch_go_button();
 
 	///
 	bool at_ref_;
