@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file FormSearch.h
- * Copyright 2001 The LyX Team.
- * See the file COPYING.
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven, leuven@fee.uva.nl
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMSEARCH_H
@@ -17,15 +19,14 @@
 #include "FormBase.h"
 
 class ControlSearch;
-struct FD_form_search;
+struct FD_search;
 
 /** This class provides an XForms implementation of the FormSearch Dialog.
  */
-class FormSearch : public FormCB<ControlSearch, FormDB<FD_form_search> > {
+class FormSearch : public FormCB<ControlSearch, FormDB<FD_search> > {
 public:
 	///
-	FormSearch(ControlSearch &);
-
+	FormSearch();
 private:
 	/// not needed.
 	virtual void apply() {}
@@ -36,9 +37,6 @@ private:
 
 	/// Filter the inputs
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
-
-	/// Fdesign generated method
-	FD_form_search  * build_search();
 };
 
 #endif // FORMSEARCH_H
