@@ -2,10 +2,12 @@
 /**
  * \file xforms/FormTabularCreate.h
  * Copyright 1995 Matthias Ettrich
- * Copyright 1995-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Jrgen Vigna, jug@sad.it
+ * \author Jrgen Vigna
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMTABULARCREATE_H
@@ -18,17 +20,16 @@
 #include "FormBase.h"
 
 class ControlTabularCreate;
-struct FD_form_tabular_create;
+struct FD_tabular_create;
 
 /** This class provides an XForms implementation of the TabularCreate
     Dialog.
  */
 class FormTabularCreate :
-	public FormCB<ControlTabularCreate, FormDB<FD_form_tabular_create> > {
+	public FormCB<ControlTabularCreate, FormDB<FD_tabular_create> > {
 public:
 	///
-	FormTabularCreate(ControlTabularCreate &);
-
+	FormTabularCreate();
 private:
 	/// Apply from dialog
 	virtual void apply();
@@ -36,9 +37,6 @@ private:
 	virtual void build();
 	/// not needed
 	virtual void update() {};
-
-	///
-	FD_form_tabular_create * build_tabular_create();
 };
 
 #endif // FORMTABULARCREATE
