@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file FormThesaurus.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon, moz@compsoc.man.ac.uk
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMTHESAURUS_H
@@ -17,20 +19,14 @@
 #include "FormBase.h"
 
 class ControlThesaurus;
-struct FD_form_thesaurus;
-struct FD_form_noun;
-struct FD_form_verb;
-struct FD_form_adjective;
-struct FD_form_adverb;
-struct FD_form_other;
+struct FD_thesaurus;
 
 /** This class provides an XForms implementation of the Thesaurus dialog.
  */
-class FormThesaurus : public FormCB<ControlThesaurus, FormDB<FD_form_thesaurus> > {
+class FormThesaurus : public FormCB<ControlThesaurus, FormDB<FD_thesaurus> > {
 public:
 	///
-	FormThesaurus(ControlThesaurus &);
-
+	FormThesaurus();
 private:
 	/// not needed.
 	virtual void apply() {}
@@ -39,9 +35,6 @@ private:
 	/// update dialog
 	virtual void update();
 
-	/// dialog build
-	FD_form_thesaurus * build_thesaurus();
-
 	/// set the replace word properly
 	void setReplace(string const & templ, string const & nstr);
 
