@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormUrl.h
- * Copyright 2000-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMURL_H
@@ -17,15 +19,14 @@
 #include "FormBase.h"
 
 class ControlUrl;
-struct FD_form_url;
+struct FD_url;
 
 /** This class provides an XForms implementation of the Url Dialog.
  */
-class FormUrl : public FormCB<ControlUrl, FormDB<FD_form_url> > {
+class FormUrl : public FormCB<ControlUrl, FormDB<FD_url> > {
 public:
 	///
-	FormUrl(ControlUrl &);
-
+	FormUrl();
 private:
 	/// Apply from dialog (modify or create inset)
 	virtual void apply();
@@ -33,8 +34,6 @@ private:
 	virtual void build();
 	/// Update dialog before showing it
 	virtual void update();
-	/// Filter the inputs on callback from xforms
-	FD_form_url * build_url();
 };
 
 #endif // FORMURL_H
