@@ -1,19 +1,19 @@
 // -*- C++ -*-
 /**
  * \file xforms/Timeout_pimpl.h
- * Copyright 2001 LyX Team
- * Read COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Lars Gullik Bjnnes, larsbj@lyx.org
- * \author John Levon, moz@compsoc.man.ac.uk
+ * \author Lars Gullik Bjnnes
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 #ifndef TIMEOUTPIMPL_H
 #define TIMEOUTPIMPL_H
 
 #include "frontends/Timeout.h"
 
-#include <sigc++/signal_system.h>
-
 #ifdef __GNUG__
 #pragma interface
 #endif
