@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file Tooltips.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 /* Tooltips for xforms. xforms 0.89 supports them directly, but 0.88 needs
@@ -16,18 +18,23 @@
 #ifndef TOOLTIPS_H
 #define TOOLTIPS_H
 
-#include "LString.h"
-#include <boost/utility.hpp>
-#include <sigc++/signal_system.h>
-#include <map>
-#include FORMS_H_LOCATION // Can't forward-declare FL_OBJECT
-
 #ifdef __GNUG__
 #pragma interface
 #endif
 
-class Tooltips : boost::noncopyable, public SigC::Object {
+#include "LString.h"
+
+#include <boost/utility.hpp>
+#include <boost/signals/signal0.hpp>
+#include <boost/signals/trackable.hpp>
+
+#include "forms_fwd.h" // Can't forward-declare FL_OBJECT
+
+#include <map>
+
+class Tooltips : boost::noncopyable, public boost::signals::trackable {
 public:
+	///
 	Tooltips();
 
 	/// Initialise a tooltip for this ob.
@@ -36,46 +43,28 @@ public:
 	/// Are the tooltips on or off?
 	static bool enabled() { return enabled_; }
 
-	/// This method is connected to the tooltipsToggled signal.
-	void set();
-
-#if FL_VERSION < 1 && FL_REVISION < 89
-
-	/** Return the tooltip associated with this object.
-	 *  Required by an xforms callback routine.
-	 */
-	string const get(FL_OBJECT *) const;
-
-#endif
-
-private:
-
-	/// Are the tooltips on or off?
-	static bool enabled_;
-
 	/** This method is connected to Dialogs::toggleTooltips and toggles
 	 *  the state of enabled_.
 	 */
 	static void toggleEnabled();
 
+private:
+
+	/// This method is connected to the Tooltips::toggled signal.
+	void set();
+
+	/// Are the tooltips on or off?
+	static bool enabled_;
+
 	/** Once enabled_ is changed, then this signal is emitted to update
 	 *  all the tooltips.
 	 */
-	static SigC::Signal0<void> toggled;
+	static boost::signal0<void> toggled;
 
 	/// The tooltips are stored so that they can be turned on and off.
 	typedef std::map<FL_OBJECT *, string> TooltipsMap;
 
 	TooltipsMap tooltipsMap;
-
-#if FL_VERSION < 1 && FL_REVISION < 89
-
-	/** A timer is started once the mouse enters an object, so that the
-	 *  tip appears a short delay afterwards.
-	 */
-	FL_OBJECT * tooltip_timer_;
-
-#endif
 };
 
 #endif // TOOLTIPS_H
