@@ -1,18 +1,20 @@
 // -*- C++ -*-
 /**
  * \file xformsBC.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Allan Rae, rae@lyx.org
- * \author Angus Leeming, a.leeming@ic.ac.uk
- * \author Baruch Even, baruch.even@writeme.com
+ * \author Allan Rae
+ * \author Angus Leeming
+ * \author Baruch Even
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef XFORMSBC_H
 #define XFORMSBC_H
 
-#include FORMS_H_LOCATION
+#include "forms_fwd.h"
 
 #ifdef __GNUG__
 #pragma interface
