@@ -1,15 +1,14 @@
 // -*- C++ -*-
 /**
  *  \file GraphicsParams.h
- *  Copyright 2002 the LyX Team
- *  Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *  \author Angus Leeming <a.leeming@ic.ac.uk>
+ *  \author Angus Leeming
  *
- *  Used internally by the GraphicsCache.
- *  Only a subset of InsetGraphicsParams is needed for display purposes.
- *  The GraphicsParams c-tor also interrogates lyxrc to ascertain whether
- *  to display or not.
+ * Full author contact details are available in file CREDITS
+ *
+ *  Used internally by the grfx::Image.
  */
 
 #ifndef GRAPHICSPARAMS_H
@@ -19,10 +18,9 @@
 #pragma interface
 #endif
 
+#include "GraphicsTypes.h"
 #include "LString.h"
-#include "lyxlength.h"
 
-class InsetGraphicsParams;
 
 namespace grfx {
 
@@ -38,29 +36,21 @@ struct BoundingBox {
 	/// 0 0 0 0 is empty!
 	bool empty() const;
 
-	int xl;
-	int yb;
-	int xr;
-	int yt;
+	unsigned int xl;
+	unsigned int yb;
+	unsigned int xr;
+	unsigned int yt;
 };
 
 bool operator==(BoundingBox const &, BoundingBox const &);
 bool operator!=(BoundingBox const &, BoundingBox const &);
 
-struct GParams
+struct Params
 {
-	GParams(InsetGraphicsParams const &, string const &);
-
-	/// How is the image to be displayed on the LyX screen?
-	enum DisplayType {
-		COLOR,
-		GRAYSCALE,
-		MONOCHROME,
-		/// We aren't going to display it at all!
-		NONE
-	};
+	Params();
 
 	DisplayType display;
+	unsigned int scale;
 
 	/// The image filename.
 	string filename;
@@ -74,16 +64,12 @@ struct GParams
 	/** The size of the view inside lyx in pixels or the scaling of the
 	 *  image.
 	 */
-	unsigned int width;
-	unsigned int height;
-	unsigned int scale;
-
 	/// Rotation angle.
-	int angle;
+	float angle;
 };
 
-bool operator==(GParams const &, GParams const &);
-bool operator!=(GParams const &, GParams const &);
+bool operator==(Params const &, Params const &);
+bool operator!=(Params const &, Params const &);
 
 } // namespace grfx
 
