@@ -1,12 +1,16 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file inset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Alejandro Aguilar Sierra
+ * \author Jrgen Vigna
+ * \author Lars Gullik Bjnnes
+ * \author Matthias Ettrich
  *
- *           Copyright 1995-2001 the LyX Team.
- *
- * ====================================================== */
+ * Full author contact details are available in file CREDITS
+ */
 
 #ifndef INSET_H
 #define INSET_H
@@ -17,9 +21,8 @@
 
 #include <vector>
 #include "LString.h"
-#include <X11/Xlib.h>
-#include "commandtags.h"
 #include "LColor.h"
+#include "frontends/mouse_state.h"
 
 class LyXFont;
 class BufferView;
@@ -29,9 +32,14 @@ class LyXText;
 class LyXLex;
 class Paragraph;
 class LyXCursor;
+class FuncRequest;
+class WordLangTuple;
 
 struct LaTeXFeatures;
 
+namespace grfx {
+	class PreviewLoader;
+}
 
 /// Insets
 class Inset {
@@ -63,7 +71,7 @@ public:
 		///
 		LABEL_CODE, // 10
 		///
-		IGNORE_CODE,
+		NOTE_CODE,
 		///
 		ACCENT_CODE,
 		///
@@ -89,6 +97,8 @@ public:
 		///
 		FLOAT_CODE,
 		///
+		WRAP_CODE,
+		///
 		MINIPAGE_CODE,
 		///
 		SPECIALCHAR_CODE, // 25
@@ -111,7 +121,9 @@ public:
 		///
 		FLOAT_LIST_CODE,
 		///
-		INDEX_PRINT_CODE
+		INDEX_PRINT_CODE,
+		///
+		OPTARG_CODE
 	};
 
 	///
@@ -130,6 +142,35 @@ public:
 		HIGHLY_EDITABLE
 	};
 
+	/** Dispatch result codes
+	    Now that nested updatable insets are allowed, the local dispatch
+	    becomes a bit complex, just two possible results (boolean)
+	    are not enough.
+
+	    DISPATCHED          = the inset catched the action
+	    DISPATCHED_NOUPDATE = the inset catched the action and no update
+				  is needed here to redraw the inset
+	    FINISHED            = the inset must be unlocked as a result
+				  of the action
+	    FINISHED_RIGHT      = FINISHED, but put the cursor to the RIGHT of
+				  the inset.
+	    FINISHED_UP         = FINISHED, but put the cursor UP of
+				  the inset.
+	    FINISHED_DOWN       = FINISHED, but put the cursor DOWN of
+				  the inset.
+	    UNDISPATCHED        = the action was not catched, it should be
+				  dispatched by lower level insets
+	*/
+	enum RESULT {
+		UNDISPATCHED = 0,
+		DISPATCHED,
+		DISPATCHED_NOUPDATE,
+		FINISHED,
+		FINISHED_RIGHT,
+		FINISHED_UP,
+		FINISHED_DOWN
+	};
+
 	///
 	Inset();
 	///
@@ -151,21 +192,13 @@ public:
 	/// what appears in the minibuffer when opening
 	virtual string const editMessage() const;
 	///
-	virtual void edit(BufferView *, int x, int y, unsigned int button);
+	virtual void edit(BufferView *, int x, int y, mouse_button::state button);
 	///
 	virtual void edit(BufferView *, bool front = true);
 	///
 	virtual EDITABLE editable() const;
-	/// This is called when the user clicks inside an inset
-	virtual void insetButtonPress(BufferView *, int, int, int) {}
-	/// This is called when the user releases the button inside an inset
-	// the bool return is used to see if we opened a dialog so that we can
-	// check this from an outer inset and open the dialog of the
-	// outer inset if that one has one!
-	virtual bool insetButtonRelease(BufferView *, int, int, int)
-		{ return editable() == IS_EDITABLE; }
-	/// This is called when the user moves the mouse inside an inset
-	virtual void insetMotionNotify(BufferView *, int , int , int) {}
+	///
+	virtual RESULT localDispatch(FuncRequest const & cmd);
 	///
 	virtual bool isTextInset() const { return false; }
 	///
@@ -194,7 +227,7 @@ public:
 	///
 	virtual int linuxdoc(Buffer const *, std::ostream &) const = 0;
 	///
-	virtual int docbook(Buffer const *, std::ostream &) const = 0;
+	virtual int docbook(Buffer const *, std::ostream &, bool) const = 0;
 	/// Updates needed features for this inset.
 	virtual void validate(LaTeXFeatures & features) const;
 	///
@@ -317,8 +350,8 @@ public:
 	// paragraphs with "Standard" layout?
 	virtual bool forceDefaultParagraphs(Inset const *) const;
 	/** returns true if, when outputing LaTeX, font changes should
-            be closed before generating this inset. This is needed for
-            insets that may contain several paragraphs */
+	    be closed before generating this inset. This is needed for
+	    insets that may contain several paragraphs */
 	virtual bool noFontChange() const { return false; }
 	//
 	virtual void getDrawFont(LyXFont &) const {}
@@ -328,6 +361,22 @@ public:
 	   minipage somewhere, it will be the width of this minipage */
 	virtual int latexTextWidth(BufferView *) const;
 
+	/** Adds a LaTeX snippet to the Preview Loader for transformation
+	 *  into a bitmap image. Does not start the laoding process.
+	 *
+	 *  Most insets have no interest in this capability, so the method
+	 *  defaults to empty.
+	 */
+	virtual void addPreview(grfx::PreviewLoader &) const {}
+
+	/** Find the PreviewLoader, add a LaTeX snippet to it and
+	 *  start the loading process.
+	 *
+	 *  Most insets have no interest in this capability, so the method
+	 *  defaults to empty.
+	 */
+	virtual void generatePreview() const {}
+
 protected:
 	///
 	mutable int top_x;
@@ -395,40 +444,6 @@ bool Inset::checkInsertChar(LyXFont &)
  */
 class UpdatableInset : public Inset {
 public:
-	/** Dispatch result codes
-	    Now that nested updatable insets are allowed, the local dispatch
-	    becomes a bit complex, just two possible results (boolean)
-	    are not enough.
-
-	    DISPATCHED          = the inset catched the action
-	    DISPATCHED_NOUPDATE = the inset catched the action and no update
-				  is needed here to redraw the inset
-	    FINISHED            = the inset must be unlocked as a result
-				  of the action
-	    FINISHED_RIGHT      = FINISHED, but put the cursor to the RIGHT of
-				  the inset.
-	    FINISHED_UP         = FINISHED, but put the cursor UP of
-				  the inset.
-	    FINISHED_DOWN       = FINISHED, but put the cursor DOWN of
-				  the inset.
-	    UNDISPATCHED        = the action was not catched, it should be
-				  dispatched by lower level insets
-	*/
-	enum RESULT {
-		UNDISPATCHED = 0,
-		DISPATCHED,
-		DISPATCHED_NOUPDATE,
-		FINISHED,
-		FINISHED_RIGHT,
-		FINISHED_UP,
-		FINISHED_DOWN
-	};
-
-	/// To convert old binary dispatch results
-	RESULT DISPATCH_RESULT(bool b) {
-		return b ? DISPATCHED : FINISHED;
-	}
-
 	///
 	UpdatableInset();
 	///
@@ -451,22 +466,9 @@ public:
 	///
 	virtual void getCursorPos(BufferView *, int &, int &) const {}
 	///
-	virtual void insetButtonPress(BufferView *, int x, int y, int button);
-	///
-	// the bool return is used to see if we opened a dialog so that we can
-	// check this from an outer inset and open the dialog of the outer inset
-	// if that one has one!
-	///
-	virtual bool insetButtonRelease(BufferView *,
-					int x, int y, int button);
-	///
-	virtual void insetKeyPress(XKeyEvent * ev);
-	///
-	virtual void insetMotionNotify(BufferView *, int x, int y, int state);
-	///
 	virtual void insetUnlock(BufferView *);
 	///
-	virtual void edit(BufferView *, int x, int y, unsigned int button);
+	virtual void edit(BufferView *, int x, int y, mouse_button::state button);
 	///
 	virtual void edit(BufferView *, bool front = true);
 	///
@@ -494,7 +496,7 @@ public:
 					bool /*lr*/ = false)
 		{ return false; }
 	///  An updatable inset could handle lyx editing commands
-	virtual RESULT localDispatch(BufferView *, kb_action, string const &);
+	virtual RESULT localDispatch(FuncRequest const & cmd);
 	///
 	bool isCursorVisible() const { return cursor_visible_; }
 	///
@@ -519,7 +521,8 @@ public:
 	///
 	virtual bool allowSpellcheck() { return false; }
 	///
-	virtual string const selectNextWordToSpellcheck(BufferView *, float & value) const;
+	virtual WordLangTuple const
+	selectNextWordToSpellcheck(BufferView *, float & value) const;
 	///
 	virtual void selectSelectedWord(BufferView *) { return; }
 	///
