@@ -1,15 +1,14 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file insetcaption.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Lars Gullik Bjnnes
  *
- *           Copyright 2000-2001 The LyX Team.
- *
- *======================================================
+ * Full author contact details are available in file CREDITS
  */
 
-
 #ifndef INSETCAPTION_H
 #define INSETCAPTION_H
 
@@ -54,7 +53,7 @@ public:
 	int ascii(Buffer const * buf, std::ostream & os, int linelen) const;
 	///
 	virtual
-	int docbook(Buffer const * buf, std::ostream & os) const;
+	int docbook(Buffer const * buf, std::ostream & os, bool mixcont) const;
 protected:
 private:
 };
