@@ -1,15 +1,14 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file insetert.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Jrgen Vigna
+ * \author Lars Gullik Bjnnes
  *
- *           Copyright 1998 The LyX Team.
- *
- *======================================================
+ * Full author contact details are available in file CREDITS
  */
-// The pristine updatable inset: Text
-
 
 #ifndef INSETERT_H
 #define INSETERT_H
@@ -19,7 +18,8 @@
 #endif
 
 #include "insetcollapsable.h"
-#include <sigc++/signal_system.h>
+
+#include <boost/signals/signal0.hpp>
 
 /** A collapsable text inset for LaTeX insertions.
 
@@ -67,19 +67,13 @@ public:
 	void setFont(BufferView *, LyXFont const &,
 			     bool toggleall = false, bool selectall = false);
 	///
-	void edit(BufferView *, int, int, unsigned int);
+	void edit(BufferView *, int, int, mouse_button::state);
 	///
 	void edit(BufferView * bv, bool front = true);
 	///
 	EDITABLE editable() const;
 	///
-	SigC::Signal0<void> hideDialog;
-	///
-	void insetButtonPress(BufferView *, int x, int y, int button);
-	///
-	bool insetButtonRelease(BufferView * bv, int x, int y, int button);
-	///
-	void insetMotionNotify(BufferView *, int x, int y, int state);
+	boost::signal0<void> hideDialog;
 	///
 	int latex(Buffer const *, std::ostream &, bool fragile,
 		  bool free_spc) const;
@@ -89,12 +83,11 @@ public:
 	///
 	int linuxdoc(Buffer const *, std::ostream &) const;
 	///
-	int docbook(Buffer const *, std::ostream &) const;
+	int docbook(Buffer const *, std::ostream &, bool mixcont) const;
 	///
 	void validate(LaTeXFeatures &) const {}
 	///
-	UpdatableInset::RESULT localDispatch(BufferView *, kb_action,
-					     string const &);
+	RESULT localDispatch(FuncRequest const &);
 	///
 	bool checkInsertChar(LyXFont &);
 	///
@@ -113,7 +106,9 @@ public:
 	void close(BufferView *) const;
 	///
 	bool allowSpellcheck() { return false; }
-	string const selectNextWordToSpellcheck(BufferView *, float &) const;
+
+	WordLangTuple const
+	selectNextWordToSpellcheck(BufferView *, float &) const;
 	///
 	int ascent(BufferView *, LyXFont const &) const;
 	///
@@ -138,6 +133,16 @@ public:
 	void update(BufferView *, LyXFont const &, bool =false);
 
 private:
+	///
+	void lfunMousePress(FuncRequest const &);
+	///
+	// the bool return is used to see if we opened a dialog so that we can
+	// check this from an outer inset and open the dialog of the outer inset
+	// if that one has one!
+	///
+	bool lfunMouseRelease(FuncRequest const &);
+	///
+	void lfunMouseMotion(FuncRequest const &);
 	///
 	void init();
 	///
