@@ -1,15 +1,14 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file insetfoot.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Jrgen Vigna
+ * \author Lars Gullik Bjnnes
  *
- *           Copyright 1998 The LyX Team.
- *
- *======================================================
+ * Full author contact details are available in file CREDITS
  */
-// The pristine updatable inset: Text
-
 
 #ifndef INSETFOOT_H
 #define INSETFOOT_H
@@ -37,7 +36,7 @@ public:
 	///
 	int latex(Buffer const *, std::ostream &, bool fragile, bool fp) const;
 	///
-	int docbook(Buffer const *, std::ostream &) const;
+	int docbook(Buffer const *, std::ostream &, bool mixcont) const;
 	///
 	string const editMessage() const;
 };
