@@ -1,12 +1,12 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file insettabular.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Jrgen Vigna
  *
- *           Copyright 1995-2001 The LyX Team.
- *
- *======================================================
+ * Full author contact details are available in file CREDITS
  */
 // This is the rewrite of the tabular (table) support.
 
@@ -45,9 +45,6 @@
 #ifndef INSETTABULAR_H
 #define INSETTABULAR_H
 
-#include <sigc++/signal_system.h>
-#include <boost/smart_ptr.hpp>
-
 #ifdef __GNUG__
 #pragma interface
 #endif
@@ -58,6 +55,10 @@
 #include "lyxcursor.h"
 #include "FuncStatus.h"
 
+#include <boost/scoped_ptr.hpp>
+
+#include <boost/signals/signal0.hpp>
+
 class LyXLex;
 class Painter;
 class BufferView;
@@ -100,7 +101,7 @@ public:
 	///
 	string const editMessage() const;
 	///
-	void edit(BufferView *, int x, int y, unsigned int);
+	void edit(BufferView *, int x, int y, mouse_button::state);
 	///
 	void edit(BufferView * bv, bool front = true);
 	///
@@ -129,22 +130,13 @@ public:
 	///
 	bool isTextInset() const { return true; }
 	/** returns true if, when outputing LaTeX, font changes should
-            be closed before generating this inset. This is needed for
-            insets that may contain several paragraphs */
+	    be closed before generating this inset. This is needed for
+	    insets that may contain several paragraphs */
 	bool noFontChange() const { return true; }
 	///
 	bool display() const { return tabular->IsLongTabular(); }
 	///
-	bool insetButtonRelease(BufferView *, int, int, int);
-	///
-	void insetButtonPress(BufferView *, int, int, int);
-	///
-	void insetMotionNotify(BufferView *, int, int, int);
-	///
-	void insetKeyPress(XKeyEvent *);
-	///
-	UpdatableInset::RESULT localDispatch(BufferView *, kb_action,
-					     string const &);
+	RESULT localDispatch(FuncRequest const &);
 	///
 	int latex(Buffer const *, std::ostream &, bool, bool) const;
 	///
@@ -152,7 +144,7 @@ public:
 	///
 	int linuxdoc(Buffer const *, std::ostream &) const;
 	///
-	int docbook(Buffer const *, std::ostream &) const;
+	int docbook(Buffer const *, std::ostream &, bool mixcont) const;
 	///
 	void validate(LaTeXFeatures & features) const;
 	///
@@ -217,8 +209,12 @@ public:
 	LyXCursor const & cursor(BufferView *) const;
 	///
 	bool allowSpellcheck() { return true; }
-	string const selectNextWordToSpellcheck(BufferView *, float & value) const;
+	///
+	WordLangTuple const
+	selectNextWordToSpellcheck(BufferView *, float & value) const;
+	///
 	void selectSelectedWord(BufferView *);
+	///
 	void toggleSelection(BufferView *, bool kill_selection);
 	///
 	bool searchForward(BufferView *, string const &,
@@ -230,14 +226,31 @@ public:
 	// "normal" means without width set!
 	bool forceDefaultParagraphs(Inset const * in) const;
 
+	///
+	void addPreview(grfx::PreviewLoader &) const;
+
 	//
 	// Public structures and variables
 	///
 	boost::scoped_ptr<LyXTabular> tabular;
 	///
-	SigC::Signal0<void> hideDialog;
+	boost::signal0<void> hideDialog;
 
+	/// are some cells selected ?
+	bool hasSelection() const {
+		return has_selection;
+	}
 private:
+	///
+	void lfunMousePress(FuncRequest const &);
+	///
+	// the bool return is used to see if we opened a dialog so that we can
+	// check this from an outer inset and open the dialog of the outer inset
+	// if that one has one!
+	///
+	bool lfunMouseRelease(FuncRequest const &);
+	///
+	void lfunMouseMotion(FuncRequest const &);
 	///
 	bool calculate_dimensions_of_cells(BufferView *, LyXFont const &,
 					   bool = false) const;
@@ -256,13 +269,13 @@ private:
 	///
 	void setPos(BufferView *, int x, int y) const;
 	///
-	UpdatableInset::RESULT moveRight(BufferView *, bool lock = true);
+	RESULT moveRight(BufferView *, bool lock = true);
 	///
-	UpdatableInset::RESULT moveLeft(BufferView *, bool lock = true);
+	RESULT moveLeft(BufferView *, bool lock = true);
 	///
-	UpdatableInset::RESULT moveUp(BufferView *, bool lock = true);
+	RESULT moveUp(BufferView *, bool lock = true);
 	///
-	UpdatableInset::RESULT moveDown(BufferView *, bool lock = true);
+	RESULT moveDown(BufferView *, bool lock = true);
 	///
 	bool moveNextCell(BufferView *, bool lock = false);
 	///
@@ -276,10 +289,6 @@ private:
 	///
 	void removeTabularRow();
 	///
-	bool hasSelection() const {
-		return has_selection;
-	}
-	///
 	void clearSelection() const {
 		sel_cell_start = sel_cell_end = 0;
 		has_selection = false;
@@ -291,11 +300,11 @@ private:
 	}
 	///
 	bool activateCellInset(BufferView *, int x = 0, int y = 0,
-			       int button = 0,
+			       mouse_button::state button = mouse_button::none,
 			       bool behind = false);
 	///
 	bool activateCellInsetAbs(BufferView *, int x = 0, int y = 0,
-				  int button = 0);
+				  mouse_button::state button = mouse_button::none);
 	///
 	bool insetHit(BufferView * bv, int x, int y) const;
 	///
@@ -314,7 +323,7 @@ private:
 	void getSelection(int & scol, int & ecol,
 			  int & srow, int & erow) const;
 	///
-	string selectNextWordInt(BufferView *, float & value) const;
+	WordLangTuple selectNextWordInt(BufferView *, float & value) const;
 	///
 	bool insertAsciiString(BufferView *, string const & buf, bool usePaste);
 
