@@ -1,13 +1,13 @@
 // -*- C++ -*-
-/* This file is part of*
- * ======================================================
+/**
+ * \file insettoc.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Word Processor
+ * \author Lars Gullik Bjnnes
  *
- *           Copyright 1995 Matthias Ettrich
- *           Copyright 1996-2001 The LyX Team.
- *
- * ====================================================== */
+ * Full author contact details are available in file CREDITS
+ */
 
 #ifndef INSET_TOC_H
 #define INSET_TOC_H
@@ -32,7 +32,7 @@ public:
 	///
 	string const getScreenLabel(Buffer const *) const;
 	///
-	void edit(BufferView * bv, int, int, unsigned int);
+	void edit(BufferView * bv, int, int, mouse_button::state);
 	///
 	void edit(BufferView * bv, bool front = true);
 	///
@@ -46,7 +46,7 @@ public:
 	///
 	int linuxdoc(Buffer const *, std::ostream &) const;
 	///
-	int docbook(Buffer const *, std::ostream &) const;
+	int docbook(Buffer const *, std::ostream &, bool mixcont) const;
 };
 
 #endif
