@@ -38,28 +38,22 @@ public:
 	///
 	typedef ClassList::const_iterator const_iterator;
 	///
-	const_iterator begin() const { return classlist.begin(); }
+	const_iterator begin() const { return classlist_.begin(); }
 	///
-	const_iterator end() const { return classlist.end(); }
+	const_iterator end() const { return classlist_.end(); }
 
-	/** Gets textclass number from name.
-	    Returns -1 if textclass name does not exist
-	*/
+	/// Gets textclass number from name, -1 if textclass name does not exist
 	std::pair<bool, lyx::textclass_type> const
 	NumberOfClass(string const & textclass) const;
 
 	///
 	LyXTextClass const & operator[](lyx::textclass_type textclass) const;
 
-	/** Read textclass list.
-	    Returns false if this fails
-	*/
+	/// Read textclass list.  Returns false if this fails.
 	bool Read();
 private:
 	///
-	mutable ClassList classlist;
-	///
-	void Add(LyXTextClass const &);
+	mutable ClassList classlist_;
 };
 
 ///
