@@ -7,6 +7,14 @@
 #pragma interface
 #endif
 
+/**
+ * Wrapper for MathInset * with copy-semantics
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS
+ */
+
 /**
 The 'atom' is the major blob in math typesetting.  And 'atom' consists
 of a nucleus, an optional superscript, and an optional subscript.
@@ -45,12 +53,10 @@ public:
 	~MathAtom();
 	/// assignment invokes nucleus_->clone()
 	void operator=(MathAtom const &);
-	/// change inset under the hood
-	void reset(MathInset * p);
 	/// access to the inset (checked with gprof)
-	MathInset * nucleus() const { return nucleus_; }
+	MathInset       * nucleus()       { return nucleus_; }
 	/// access to the inset
-	MathInset * operator->() const { return nucleus_; }
+	MathInset const * operator->() const { return nucleus_; }
 
 private:
 	///
