@@ -9,12 +9,12 @@
 #endif
 
 /** Binom like objects
-    \author Andr Pnitz
+ *  \author Andr Pnitz
  */
 class MathBinomInset : public MathFracbaseInset {
 public:
 	///
-	MathBinomInset();
+	explicit MathBinomInset(bool choose = false);
 	///
 	MathInset * clone() const;
 	///
@@ -22,12 +22,14 @@ public:
 	///
 	void normalize(NormalStream &) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 private:
 	///
 	int dw() const;
+	///
+	bool choose_;
 };
 
 #endif
