@@ -3,14 +3,15 @@
 #define MATH_BRACEINSET_H
 
 #include "math_nestinset.h"
-#include "math_metricsinfo.h"
 
 #ifdef __GNUG__
 #pragma interface
 #endif
 
 /** Extra nesting
-    \author Andr Pnitz
+ *  \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS
 */
 
 class MathBraceInset : public MathNestInset {
@@ -18,25 +19,33 @@ public:
 	///
 	MathBraceInset();
 	///
-	MathInset * clone() const;
+	MathBraceInset(MathArray const & ar);
 	///
-	MathBraceInset * asBraceInset() { return this; }
-	/// identifies things that add {...} when written
+	MathInset * clone() const;
+	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	void draw(Painter &, int x, int y) const;
+	void metrics(MathMetricsInfo & mi) const;
+	///
+	void draw(MathPainterInfo &, int x, int y) const;
 	///
 	void write(WriteStream & os) const;
 	/// write normalized content
-	void normalize(NormalStream &) const;
+	void normalize(NormalStream & ns) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void maplize(MapleStream &) const;
+	///
+	void mathematicize(MathematicaStream &) const;
+	///
+	void octavize(OctaveStream &) const;
+	///
+	void mathmlize(MathMLStream &) const;
+	///
+	void infoize(std::ostream & os) const;
 
 private:
 	/// width of brace character
 	mutable int wid_;
-	///
-	mutable LyXFont font_;
 };
 
 #endif
