@@ -16,10 +16,12 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter & pain, int x, int y) const;
+	void draw(MathPainterInfo & pain, int x, int y) const;
 
+	///
+	void infoize(std::ostream & os) const;
 	///
 	void normalize(NormalStream &) const;
 	///
