@@ -10,24 +10,30 @@
 #endif
 
 /** Decorations and accents over (below) a math object
-    \author Alejandro Aguilar Sierra
+ *  \author Alejandro Aguilar Sierra
+ *
+ * Full author contact details are available in file CREDITS
  */
 
+class latexkeys;
+
 class MathDecorationInset : public MathNestInset {
 public:
 	///
-	explicit MathDecorationInset(string const & name);
+	explicit MathDecorationInset(latexkeys const * key);
 	///
 	MathInset * clone() const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 	///
 	void write(WriteStream & os) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
 	void normalize(NormalStream & os) const;
 	///
+	void infoize(std::ostream & os) const;
+	///
 	bool isScriptable() const;
 
 private:
@@ -39,7 +45,7 @@ private:
 	bool wide() const;
 
 	///
-	string const name_;
+	latexkeys const * key_;
 	/// height cache of deco
 	mutable int dh_;
 	/// vertical offset cache of deco
