@@ -10,7 +10,9 @@
 #endif
 
 /** A delimiter
-    \author Alejandro Aguilar Sierra
+ *  \author Alejandro Aguilar Sierra
+ *
+ * Full author contact details are available in file CREDITS
 */
 
 class MathDelimInset : public MathNestInset {
@@ -18,6 +20,8 @@ public:
 	///
 	MathDelimInset(string const & left, string const & right);
 	///
+	MathDelimInset(string const & left, string const & right, MathArray const &);
+	///
 	MathInset * clone() const;
 	///
 	MathDelimInset * asDelimInset() { return this; }
@@ -30,9 +34,9 @@ public:
 	/// is it |...|?
 	bool isAbs() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 
 	///
 	void write(WriteStream & os) const;
@@ -41,6 +45,10 @@ public:
 	///
 	void maplize(MapleStream &) const;
 	///
+	void maximize(MaximaStream &) const;
+	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void octavize(OctaveStream &) const;
