@@ -2,6 +2,10 @@
 #ifndef MATH_DIFFINSET_H
 #define MATH_DIFFINSET_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 // d f(x)/dx in one block
 // for interfacing external programs
 
@@ -16,15 +20,17 @@ public:
 	///
 	void addDer(MathArray const & der);
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo & pi, int x, int y) const;
 
 	///
 	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
 	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void write(WriteStream & os) const;
