@@ -1,6 +1,10 @@
 #ifndef MATH_FACTORY_H
 #define MATH_FACTORY_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "LString.h"
 #include "math_atom.h"
 
@@ -8,6 +12,5 @@ class MathInset;
 class latexkeys;
 
 MathAtom createMathInset(string const &);
-MathAtom createMathInset(latexkeys const *);
 
 #endif
