@@ -13,11 +13,11 @@ public:
 	///
 	MathFracbaseInset();
 	///
-	bool idxUpDown(idx_type &, bool up) const;
+	bool idxUpDown(idx_type & idx, pos_type & pos, bool up, int targetx) const;
 	///
-	bool idxLeft(idx_type &, pos_type &) const;
+	bool idxLeft(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxRight(idx_type &, pos_type &) const;
+	bool idxRight(idx_type & idx, pos_type & pos) const;
 };
 
 #endif
