@@ -13,11 +13,32 @@
 /** Gridded math inset base class.
     This is the base to all grid-like editable math objects
     like array and eqnarray.
-    \author Andr Pnitz 2001
+ *  \author Andr Pnitz 2001
+ *
+ * Full author contact details are available in file CREDITS
 */
 
 class MathGridInset : public MathNestInset {
 
+public:
+
+	/// additional per-cell information
+	struct CellInfo {
+		///
+		CellInfo();
+		/// a dummy cell before a multicolumn cell
+		int dummy_;
+		/// special multi colums alignment
+		string align_;
+		/// these should be a per-cell property, but ok to have it here
+		/// for single-column grids like paragraphs
+		mutable int glue_;
+		///
+		mutable pos_type begin_;
+		///
+		mutable pos_type end_;
+	};
+
 	/// additional per-row information
 	struct RowInfo {
 		///
@@ -61,6 +82,8 @@ class MathGridInset : public MathNestInset {
 	};
 
 public:
+	/// sets nrows and ncols to 1
+	MathGridInset();
 	/// constructor from columns description, creates one row
 	MathGridInset(char valign, string const & halign);
 	/// Note: columns first!
@@ -70,15 +93,15 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo & pi, int x, int y) const;
 	///
-	void metricsT(TextMetricsInfo const & st) const;
+	void metricsT(TextMetricsInfo const & mi) const;
 	///
-	void drawT(TextPainter &, int x, int y) const;
+	void drawT(TextPainter & pi, int x, int y) const;
 	///
-	void halign(string const &);
+	void halign(string const & align);
 	///
 	void halign(char c, col_type col);
 	///
@@ -99,8 +122,16 @@ public:
 	const RowInfo & rowinfo(row_type row) const;
 	/// returns topmost row if passed (-1)
 	RowInfo & rowinfo(row_type row);
+	///
+	const CellInfo & cellinfo(idx_type idx) const { return cellinfo_[idx]; }
+	///
+	CellInfo & cellinfo(idx_type idx) { return cellinfo_[idx]; }
 	/// identifies GridInset
-	virtual MathGridInset * asGridInset() { return this; }
+	MathGridInset * asGridInset() { return this; }
+	/// identifies GridInset
+	MathGridInset const * asGridInset() const { return this; }
+	/// local dispatcher
+	result_type dispatch(FuncRequest const & cmd, idx_type & idx, pos_type & pos);
 
 	///
 	col_type ncols() const;
@@ -110,44 +141,48 @@ public:
 	col_type col(idx_type idx) const;
 	///
 	row_type row(idx_type idx) const;
-	///
-	int cellXOffset(idx_type idx) const;
-	///
-	int cellYOffset(idx_type idx) const;
 
 	///
-	bool idxUpDown(idx_type &, bool) const;
+	bool idxUpDown(idx_type & idx, pos_type & pos, bool up, int targetx) const;
 	///
-	bool idxLeft(idx_type &, pos_type &) const;
+	bool idxLeft(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxRight(idx_type &, pos_type &) const;
+	bool idxRight(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxFirst(idx_type &, pos_type &) const;
+	bool idxFirst(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxLast(idx_type &, pos_type &) const;
+	bool idxLast(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxHome(idx_type &, pos_type &) const;
+	bool idxHome(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxEnd(idx_type &, pos_type &) const;
+	bool idxEnd(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxDelete(idx_type &);
+	bool idxDelete(idx_type & idx);
 	/// pulls cell after pressing erase
 	void idxGlue(idx_type idx);
 
 	///
-	virtual void addRow(row_type);
+	virtual void addRow(row_type r);
 	///
-	virtual void delRow(row_type);
+	virtual void delRow(row_type r);
 	///
-	virtual void addCol(col_type);
+	virtual void copyRow(row_type r);
 	///
-	virtual void delCol(col_type);
+	virtual void swapRow(row_type r);
+	///
+	virtual void addCol(col_type c);
+	///
+	virtual void delCol(col_type c);
+	///
+	virtual void copyCol(col_type c);
+	///
+	virtual void swapCol(col_type c);
 	///
 	virtual void appendRow();
 	///
-	idx_type index(row_type row, col_type col) const;
+	idx_type index(row_type r, col_type c) const;
 	///
-	std::vector<idx_type> idxBetween(idx_type from, idx_type to) const;
+	bool idxBetween(idx_type idx, idx_type from, idx_type to) const;
 	///
 	virtual int defaultColSpace(col_type) { return 0; }
 	///
@@ -178,17 +213,26 @@ public:
 	//void octavize(OctaveStream &) const;
 
 protected:
+	/// returns x offset of cell compared to inset
+	int cellXOffset(idx_type idx) const;
+	/// returns y offset of cell compared to inset
+	int cellYOffset(idx_type idx) const;
 	/// returns proper 'end of line' code for LaTeX
-	string eolString(row_type row, bool fragile = false) const;
+	virtual string eolString(row_type row, bool fragile = false) const;
 	/// returns proper 'end of column' code for LaTeX
-	string eocString(col_type col) const;
+	virtual string eocString(col_type col, col_type lastcol) const;
 	/// extract number of columns from alignment string
 	col_type guessColumns(string const & halign) const;
+	/// splits cells and shifts right part to the next cell
+	void splitCell(idx_type &, pos_type & pos);
 
+public:
 	/// row info
 	std::vector<RowInfo> rowinfo_;
 	/// column info
 	std::vector<ColInfo> colinfo_;
+	/// cell info
+	std::vector<CellInfo> cellinfo_;
 	///
 	char v_align_; // add approp. type
 };
