@@ -17,12 +17,12 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void draw(Painter &, int x, int y) const;
+	string name() const;
 	///
-	void write(WriteStream & os) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
-	void normalize(NormalStream &) const;
+	void draw(MathPainterInfo & pi, int x, int y) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void infoize(std::ostream & os) const;
 };
 #endif
