@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/*
+/**
  *  File:        math_macro.h
  *  Purpose:     Declaration of macro class for mathed
  *  Author:      Alejandro Aguilar Sierra <asierra@servidor.unam.mx>
@@ -21,10 +21,8 @@
 #pragma interface
 #endif
 
-#include <vector>
-#include <iosfwd>
-
 #include "math_nestinset.h"
+#include "math_metricsinfo.h"
 #include "math_macroarg.h"
 #include "LString.h"
 
@@ -32,7 +30,9 @@ class MathMacroTemplate;
 
 
 /** This class contains the data for a macro
-    \author Alejandro Aguilar Sierra <asierra@servidor.unam.mx>
+ *  \author Alejandro Aguilar Sierra
+ *
+ * Full author contact details are available in file CREDITS
     \version November 1996
  */
 class MathMacro : public MathNestInset {
@@ -42,30 +42,28 @@ public:
 	///
 	MathMacro(MathMacro const &);
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo & pi, int x, int y) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
 	MathInset * clone() const;
 	///
 	void dump() const;
 
 	///
-	bool idxUpDown(idx_type &, bool up) const;
+	bool idxUpDown(idx_type & idx, pos_type & pos, bool up, int targetx) const;
 	///
-	bool idxLeft(idx_type &, pos_type &) const;
+	bool idxLeft(idx_type & idx, pos_type & pos) const;
 	///
-	bool idxRight(idx_type &, pos_type &) const;
+	bool idxRight(idx_type & idx, pos_type & pos) const;
 
 	///
 	void validate(LaTeXFeatures &) const;
 	///
 	bool isMacro() const { return true; }
 	///
-	bool match(MathInset *) const { return false; }
+	bool match(MathAtom const &) const { return false; }
 
-	///
-	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
 	///
@@ -73,13 +71,15 @@ public:
 	///
 	void octavize(OctaveStream &) const;
 	///
-	void write(WriteStream & os) const;
+	void infoize(std::ostream &) const;
+	///
+	void infoize2(std::ostream &) const;
 
 private:
 	///
 	void operator=(MathMacro const &);
 	///
-	string const & name() const;
+	string name() const;
 	///
 	bool defining() const;
 	///
@@ -90,7 +90,7 @@ private:
 	///
 	MathAtom & tmplate_;
 	///
-	mutable MathXArray expanded_;
+	mutable MathArray expanded_;
 	///
 	mutable MathMetricsInfo mi_;
 	///
