@@ -12,7 +12,9 @@
 class MathMacro;
 
 /** This class contains the macro definition
-    \author Alejandro Aguilar Sierra
+ *  \author Alejandro Aguilar Sierra
+ *
+ * Full author contact details are available in file CREDITS
  */
 //class MathMacroTemplate : public MathInset, boost::noncopyable
 
@@ -21,7 +23,10 @@ public:
 	///
 	MathMacroTemplate();
 	///
-	MathMacroTemplate(string const & name, int nargs);
+	MathMacroTemplate(string const & name, int nargs,
+		MathArray const & = MathArray(), MathArray const & = MathArray());
+	///
+	explicit MathMacroTemplate(std::istream & is);
 	///
 	MathInset * clone() const;
 	///
@@ -31,13 +36,15 @@ public:
 	///
 	void numargs(int);
 	///
-	string const & name() const;
+	string name() const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	/// identifies macro templates
 	MathMacroTemplate * asMacroTemplate() { return this; }
+	/// identifies macro templates
+	MathMacroTemplate const * asMacroTemplate() const { return this; }
 private:
 	///
 	int numargs_;
