@@ -1,8 +1,12 @@
 #ifndef MATH_POS_H
 #define MATH_POS_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include <iosfwd>
-#include "math_xdata.h"
+#include "math_data.h"
 
 
 /// Description of a position
@@ -17,14 +21,10 @@ public:
 	MathArray & cell() const;
 	/// returns cell corresponding to this position
 	MathArray & cell(MathArray::idx_type idx) const;
-	/// returns xcell corresponding to this position
-	MathXArray & xcell() const;
-	/// returns xcell corresponding to this position
-	MathXArray & xcell(MathArray::idx_type idx) const;
-	///
-	int xpos() const;
-	///
-	int ypos() const;
+	/// gets screen position of the thing
+	void getPos(int & x, int & y) const;
+	/// set position
+	void setPos(MathArray::pos_type pos);
 
 public:
 	/// pointer to an inset
