@@ -1,6 +1,10 @@
 #ifndef MATH_REPLACE_H
 #define MATH_REPLACE_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "math_data.h"
 
 struct ReplaceData {
