@@ -3,14 +3,16 @@
 #define MATHSIZEINSET_H
 
 #include "math_nestinset.h"
-#include "math_defs.h"
+#include "math_metricsinfo.h"
 
 #ifdef __GNUG__
 #pragma interface
 #endif
 
 /** An inset for \scriptsize etc
-    \author Andr Pnitz
+ *  \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS
 */
 
 class latexkeys;
@@ -21,23 +23,25 @@ public:
 	explicit MathSizeInset(latexkeys const * l);
 	///
 	MathInset * clone() const;
-	/// identifies things that add {...} when written
+	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
-	///
-	bool needsBraces() const { return false; }
+	void draw(MathPainterInfo &, int x, int y) const;
 
 	///
 	void write(WriteStream & os) const;
 	///
 	void normalize(NormalStream &) const;
+	///
+	void infoize(std::ostream & os) const;
 
 private:
 	///
 	latexkeys const * key_;
+	///
+	MathStyles const style_;
 };
 
 #endif
