@@ -9,7 +9,9 @@
 #endif
 
 /** The square root inset.
-    \author Alejandro Aguilar Siearra
+ *  \author Alejandro Aguilar Siearra
+ *
+ * Full author contact details are available in file CREDITS
  */
 class MathSqrtInset : public MathNestInset {
 public:
@@ -18,9 +20,9 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 	///
-	void metrics(MathMetricsInfo const & mi) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
 	void drawT(TextPainter &, int x, int y) const;
 	///
@@ -33,6 +35,8 @@ public:
 	///
 	void maplize(MapleStream &) const;
 	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void octavize(OctaveStream &) const;
 	///
 	void mathmlize(MathMLStream &) const;
