@@ -2,6 +2,10 @@
 #ifndef MATH_SYMBOLINSET_H
 #define MATH_SYMBOLINSET_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "math_diminset.h"
 
 struct latexkeys;
@@ -20,9 +24,9 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 	///
 	bool isRelOp() const;
 	/// do we take scripts?
@@ -34,36 +38,33 @@ public:
 	/// the LaTeX name of the symbol (without the backslash)
 	string name() const;
 	///
-	bool match(MathInset *) const;
+	bool match(MathAtom const &) const;
 	/// request "external features"
 	void validate(LaTeXFeatures & features) const;
-	/// identifies complicated things that need braces if used as arg
-	bool needsBraces() const { return false; }
 
 	///
 	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
 	///
+	void maximize(MaximaStream &) const;
+	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void octavize(OctaveStream &) const;
 	///
 	void write(WriteStream & os) const;
 	///
-	void infoize(std::ostream & os) const;
+	void infoize2(std::ostream & os) const;
 
 private:
-	///
-	MathTextCodes code() const;
-	///
-	MathTextCodes code2() const;
-
 	///
 	latexkeys const * sym_;
 	///
 	mutable int h_;
 	///
-	mutable MathMetricsInfo mi_;
+	mutable bool scriptable_;
 };
 #endif
