@@ -1,16 +1,21 @@
 // -*- C++ -*-
+
+/** Underset objects
+ *  \author Andr Pnitz
+ *
+ *  Full author contact details are available in file CREDITS
+ */
+
 #ifndef MATH_UNDERSETINSET_H
 #define MATH_UNDERSETINSET_H
 
-#include "math_fracbase.h"
-
 #ifdef __GNUG__
 #pragma interface
 #endif
 
-/** Underset objects
-    \author Andr Pnitz
- */
+#include "math_fracbase.h"
+
+/// Inset for underset
 class MathUndersetInset : public MathFracbaseInset {
 public:
 	///
@@ -18,9 +23,9 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 
 	///
 	void write(WriteStream & os) const;
