@@ -3,7 +3,6 @@
 #define MATH_UNKNOWNINSET_H
 
 #include "math_diminset.h"
-#include "math_defs.h"
 
 #ifdef __GNUG__
 #pragma interface
@@ -15,36 +14,45 @@
 class MathUnknownInset : public MathDimInset {
 public:
 	///
-	explicit MathUnknownInset(string const & name);
+	explicit MathUnknownInset(string const & name,
+		bool final = true, bool black = false);
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo & pi, int x, int y) const;
 	///
-	string const & name() const;
+	void setName(string const & name);
+	///
+	string name() const;
 	/// identifies UnknownInsets
 	MathUnknownInset const * asUnknownInset() const { return this; }
+	/// identifies UnknownInsets
+	MathUnknownInset * asUnknownInset() { return this; }
 	///
-	void setName(string const &);
-	///
-	bool match(MathInset * p) const;
+	bool match(MathAtom const & at) const;
 
 	///
 	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
 	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void octavize(OctaveStream &) const;
 	///
-	void write(WriteStream &) const;
+	void finalize();
+	///
+	bool final() const;
 private:
 	///
 	string name_;
+	/// are we finished creating the name?
+	bool final_;
 	///
-	mutable LyXFont font_;
+	bool black_;
 };
 #endif
