@@ -1,13 +1,15 @@
 // -*- C++ -*-
 /**
  *  \file forkedcall.h
- *  Copyright 2002 the LyX Team
- *  Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Asger Alstrup
  *
  * Interface cleaned up by
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  *
  * An instance of Class Forkedcall represents a single child process.
  *
@@ -29,10 +31,12 @@
 #endif
 
 #include "LString.h"
-#include <sys/types.h>
-#include <boost/smart_ptr.hpp>
-#include <sigc++/signal_system.h>
 
+#include <boost/shared_ptr.hpp>
+#include <boost/signals/signal2.hpp>
+#include <boost/function/function0.hpp>
+
+#include <sys/types.h>
 
 class ForkedProcess {
 public:
@@ -60,7 +64,7 @@ public:
 	 *  we can return easily to C++ methods, rather than just globally
 	 *  accessible functions.
 	 */
-	typedef SigC::Signal2<void, pid_t, int> SignalType;
+	typedef boost::signal2<void, pid_t, int> SignalType;
 
 	/** The signal is connected in the calling routine to the desired
 	 *  slot. We pass a shared_ptr rather than a reference to the signal
@@ -94,6 +98,9 @@ public:
 	/// Returns the identifying command (for display in the GUI perhaps).
 	string const & command() const { return command_; }
 
+	/// is the process running ?
+	bool running() const;
+
 	/** Kill child prematurely.
 	 *  First, a SIGHUP is sent to the child.
 	 *  If that does not end the child process within "tolerance"
@@ -106,11 +113,11 @@ protected:
 	/** Wait for child process to finish.
 	 *  Returns returncode from child.
 	 */
-	int ForkedProcess::runBlocking();
+	int runBlocking();
 	/** Do not wait for child process to finish.
 	 *  Returns returncode from child.
 	 */
-	int ForkedProcess::runNonBlocking();
+	int runNonBlocking();
 
 	/// Callback function
 	SignalTypePtr signal_;
@@ -141,7 +148,7 @@ public:
 
 	/** Start the child process.
 	 *
-	 *  The command "what" is passed to fork() for execution.
+	 *  The command "what" is passed to execvp() for execution.
 	 *
 	 *  There are two startscript commands available. They differ in that
 	 *  the second receives a signal that is executed on completion of
