@@ -1,12 +1,14 @@
 // -*- C++ -*-
 /**
  * \file forkedcontr.h
- * Copyright 2001 The LyX Team
- * Read COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Asger Alstrup Nielsen
  * \author Angus Leeming
  *
+ * Full author contact details are available in file CREDITS
+ *
  * A class for the control of child processes launched using
  * fork() and execvp().
  */
@@ -14,11 +16,15 @@
 #ifndef FORKEDCONTR_H
 #define FORKEDCONTR_H
 
+#include "LString.h"
+
+#include <boost/signals/signal0.hpp>
+#include <boost/signals/trackable.hpp>
+
+#include <sys/types.h> // needed for pid_t
+
 #include <list>
 #include <vector>
-#include "LString.h"
-#include <sigc++/signal_system.h>
-#include <sys/types.h> // needed for pid_t
 
 #ifdef __GNUG__
 #pragma interface
@@ -27,7 +33,7 @@
 class ForkedProcess;
 class Timeout;
 
-class ForkedcallsController : public SigC::Object {
+class ForkedcallsController : public boost::signals::trackable {
 public:
 	/// We need this to avoid warnings.
 	ForkedcallsController();
@@ -62,7 +68,7 @@ public:
 	void kill(pid_t, int tolerance = 5);
 
 	/// Signal emitted when the list of current child processes changes.
-	SigC::Signal0<void> childrenChanged;
+	boost::signal0<void> childrenChanged;
 
 private:
 	///
