@@ -1,22 +1,15 @@
 // -*- C++ -*-
 /**
  *  \file systemcall.h
- *  Copyright 2002 the LyX Team
- *  Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Asger Alstrup
  *
  * Interface cleaned up by
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * \author Angus Leeming
  *
- * An instance of Class Systemcall represents a single child process.
- *
- * Class Systemcall uses system() to launch the child process.
- * The user can choose to wait or not wait for the process to complete, but no
- * callback is invoked upon completion of the child.
- *
- * The child process is not killed when the Systemcall instance goes out of
- * scope.
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef SYSTEMCALL_H
@@ -28,27 +21,24 @@
 #pragma interface
 #endif
 
+/**
+ * An instance of Class Systemcall represents a single child process.
+ *
+ * Class Systemcall uses system() to launch the child process.
+ * The user can choose to wait or not wait for the process to complete, but no
+ * callback is invoked upon completion of the child.
+ *
+ * The child process is not killed when the Systemcall instance goes out of
+ * scope.
+ */
 class Systemcall {
 public:
-	///
+	/// whether to wait for completion
 	enum Starttype {
-		///
-		Wait,
-		///
-		DontWait
+		Wait, //< wait for completion before returning from startscript()
+		DontWait //< don't wait for completion
 	};
 
-#if 0
-	///
-	Systemcall() {}
-
-	/** Generate instance and start child process.
-	 *  The string "what" contains a commandline with arguments separated
-	 *  by spaces.
-	 */
-	Systemcall(Starttype how, string const & what);
-#endif
-
 	/** Start child process.
 	 *  The string "what" contains a commandline with arguments separated
 	 *  by spaces.
