@@ -1,11 +1,11 @@
 // -*- C++ -*-
 /* This file is part of
  * ======================================================
- * 
+ *
  *           LyX, The Document Processor
- * 	 
+ *
  *           Copyright 1995 Matthias Ettrich
- *           Copyright 1995-1999 The LyX Team.
+ *           Copyright 1995-2001 The LyX Team.
  *
  * ====================================================== */
 
@@ -16,10 +16,7 @@
 #pragma interface
 #endif
 
-#include "lyxparagraph.h"
-
-#include <list>
-using std::list;
+class Paragraph;
 
 ///
 class Undo {
@@ -44,45 +41,19 @@ public:
 	///
 	int number_of_cursor_par;
 	///
+	int number_of_inset_id; // valid if >= 0, if < 0 then not in inset
+	///
 	int cursor_pos; // valid if >= 0
 	///
-	LyXParagraph * par;
+	Paragraph * par;
 	///
-	Undo(undo_kind kind_arg,
+	Undo(undo_kind kind_arg, int id_inset_arg,
 	     int number_before_arg, int number_behind_arg,
 	     int cursor_par_arg, int cursor_pos_arg,
-	     LyXParagraph * par_arg);
+	     Paragraph * par_arg);
 	///
 	~Undo();
 };
 
 
-/// A limited Stack for the undo informations.
-class UndoStack{
-private:
-	///
-	typedef list<Undo*> Stakk;
-	///
-	Stakk stakk;
-	/// the maximum number of undo steps stored.
-	Stakk::size_type limit;
-public:
-	///
-	UndoStack();
-	///
-	Undo * pop();
-	///
-	Undo * top();
-	///
-	bool empty() const;
-	///
-	~UndoStack();
-	///
-	void clear();
-	///
-	void SetStackLimit(Stakk::size_type l);
-	///
-	void push(Undo * undo_arg);
-};
-
 #endif
